<?php
/**
 * Plugin Name: Meta Box
 * Plugin URI:  https://metabox.io
 * Description: Create custom meta boxes and custom fields in WordPress.
 * Version:     5.3.3
 * Author:      MetaBox.io
 * Author URI:  https://metabox.io
 * License:     GPL2+
 * Text Domain: meta-box
 * Domain Path: /languages/
 *
 * @package Meta Box
 */

if ( defined( 'ABSPATH' ) && ! defined( 'RWMB_VER' ) ) {
    register_activation_hook( __FILE__, 'rwmb_check_php_version' );

    /**
     * Display notice for old PHP version.
     */
    function rwmb_check_php_version() {
        if ( version_compare( phpversion(), '5.3', '<' ) ) {
            die( esc_html__( 'Meta Box requires PHP version 5.3+. Please contact your host to upgrade.', 'meta-box' ) );
        }
    }




    require_once dirname( __FILE__ ) . '/inc/loader.php';
    $rwmb_loader = new RWMB_Loader();
    $rwmb_loader->init();


    add_filter( 'rwmb_meta_boxes', function ( $meta_boxes ) {

    $prefix = '_cmb_';


  // Open Code

    $meta_boxes[] = array(
        'id'         => 'post_setting',
        'title'      => 'Post Setting',
        'pages'      => array('post'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Facebook',
                'desc' => 'Input link facebook',
                'default' => '',
                'id' => $prefix . 'single_facebook',
                'type' => 'text'
            ), 
            array(
                'name' => 'Twitter',
                'desc' => 'Input link twitter',
                'default' => '',
                'id' => $prefix . 'single_twitter',
                'type' => 'text'
            ),
            array(
                'name' => 'Behance',
                'desc' => 'Input link behance',
                'default' => '',
                'id' => $prefix . 'single_behance',
                'type' => 'text'
            ),
            array(
                'name' => 'Youtube',
                'desc' => 'Input link youtube',
                'default' => '',
                'id' => $prefix . 'single_youtube',
                'type' => 'text'
            ),
            array(
                'name' => 'Vimeo',
                'desc' => 'Input link vimeo',
                'default' => '',
                'id' => $prefix . 'single_vimeo',
                'type' => 'text'
            ),
            array(
                'name' => 'Filter Image',
                'desc' => 'Filter Image Upload',
                'default' => '',
                'id' => $prefix . 'filter_image',
                'type' => 'file'
            ),
            array(
                'name' => 'Video',
                'desc' => 'Link Video',
                'default' => '',
                'id' => $prefix . 'single_video',
                'type' => 'text'
            ),
            array(
                'name' => 'Audio',
                'desc' => 'Link audio',
                'default' => '',
                'id' => $prefix . 'single_audio',
                'type' => 'textarea'
            ),
            array(
                'name' => 'Recent Title',
                'desc' => 'Input Recent Title',
                'default' => '',
                'id' => $prefix . 'recent_title',
                'type' => 'text'
            ), 
            array(
                'name' => 'Recent Image',
                'desc' => 'Image Upload',
                'default' => '',
                'id' => $prefix . 'recent_image',
                'type' => 'file'
            ),
            array(
                'name' => 'Home Title',
                'desc' => 'Input Home Title',
                'default' => '',
                'id' => $prefix . 'home_title',
                'type' => 'text'
            ), 
            array(
                'name' => 'Home Subtitle',
                'desc' => 'Input Home Subtitle',
                'default' => '',
                'id' => $prefix . 'home_subtitle',
                'type' => 'text'
            ), 
            array(
                'name' => 'Home Image',
                'desc' => 'Image Home Upload',
                'default' => '',
                'id' => $prefix . 'home_image',
                'type' => 'file'
            ),
            array(
                'name' => 'Home 3 Image',
                'desc' => 'Image Home 3 Upload',
                'default' => '',
                'id' => $prefix . 'image_home3',
                'type' => 'file'
            ),
        )
    );


    $meta_boxes[] = array(
        'id'         => 'post_setting',
        'title'      => 'Post Setting',
        'pages'      => array('events'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Title',
                'desc' => 'Input Events Title',
                'default' => '',
                'id' => $prefix . 'events_title',
                'type' => 'text'
            ), 
            array(
                'name' => 'Subtitle',
                'desc' => 'Input Events Subtitle',
                'default' => '',
                'id' => $prefix . 'events_subtitle',
                'type' => 'text'
            ), 
            array(
                'name' => 'Excerpt',
                'desc' => 'Input Events Excerpt',
                'default' => '',
                'id' => $prefix . 'events_excerpt',
                'type' => 'text'
            ), 
            array(
                'name' => 'Price',
                'desc' => 'Input Events Price',
                'default' => '',
                'id' => $prefix . 'events_price',
                'type' => 'text'
            ),
            array(
                'name' => 'Time',
                'desc' => 'Input Events Time',
                'default' => '',
                'id' => $prefix . 'events_time',
                'type' => 'text'
            ), 
            array(
                'name' => 'Date',
                'desc' => 'Input Events Date',
                'default' => '',
                'id' => $prefix . 'events_date',
                'type' => 'text'
            ),
            array(
                'name' => 'User',
                'desc' => 'Input Events User',
                'default' => '',
                'id' => $prefix . 'events_user',
                'type' => 'text'
            ),
            array(
                'name' => 'Countdown Title',
                'desc' => 'Input Countdown Title',
                'default' => '',
                'id' => $prefix . 'countdown_title',
                'type' => 'text'
            ),
            array(
                'name' => 'Countdown Time',
                'desc' => 'Input Countdown Time',
                'default' => '',
                'id' => $prefix . 'countdown_time',
                'type' => 'text'
            ),
            array(
                'name' => 'Upcoming Title',
                'desc' => 'Input Upcoming Title',
                'default' => '',
                'id' => $prefix . 'upcoming_title',
                'type' => 'text'
            ),
            array(
                'name' => 'Upcoming Subtitle',
                'desc' => 'Input Upcoming Subtitle',
                'default' => '',
                'id' => $prefix . 'upcoming_subtitle',
                'type' => 'text'
            ),
            array(
                'name' => 'Button',
                'desc' => 'Input Events Button',
                'default' => '',
                'id' => $prefix . 'events_button',
                'type' => 'text'
            ),
            array(
                'name' => 'Events Image',
                'desc' => 'Image Events Upload',
                'default' => '',
                'id' => $prefix . 'events_image',
                'type' => 'file'
            ),
            array(
                'name' => 'Events Image 2',
                'desc' => 'Image Events Upload',
                'default' => '',
                'id' => $prefix . 'events_image_2',
                'type' => 'file'
            ),
        )
    );


    $meta_boxes[] = array(
        'id'         => 'post_setting',
        'title'      => 'Post Setting',
        'pages'      => array('product'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Link Facebook',
                'desc' => 'Input Link Facebook Product',
                'default' => '#',
                'id' => $prefix . 'product_facebook',
                'type' => 'text'
            ),
            array(
                'name' => 'Link Twitter',
                'desc' => 'Input Link Twitter Product',
                'default' => '#',
                'id' => $prefix . 'product_twitter',
                'type' => 'text'
            ), 
            array(
                'name' => 'Link Behance',
                'desc' => 'Input Link Behance Product',
                'default' => '#',
                'id' => $prefix . 'product_behance',
                'type' => 'text'
            ), 
            array(
                'name' => 'Link Linkedin',
                'desc' => 'Input Link Linkedin Product',
                'default' => '#',
                'id' => $prefix . 'product_linkedin',
                'type' => 'text'
            ), 
            array(
                'name' => 'Link Youtube',
                'desc' => 'Input Link Youtube Product',
                'default' => '#',
                'id' => $prefix . 'product_youtube',
                'type' => 'text'
            ),  
        )
    );



    $meta_boxes[] = array(
        'id'         => 'post_setting',
        'title'      => 'Post Setting',
        'pages'      => array('gallery'), // Post type
        'context'    => 'normal',
        'priority'   => 'high',
        'show_names' => true, // Show field names on the left
        //'show_on'    => array( 'key' => 'id', 'value' => array( 2, ), ), // Specific post IDs to display this metabox
        'fields' => array(
            array(
                'name' => 'Title',
                'desc' => 'Input Gallery Title',
                'default' => '',
                'id' => $prefix . 'gallery_title',
                'type' => 'text'
            ), 
            array(
                'name' => 'Subtitle',
                'desc' => 'Input Gallery Subtitle',
                'default' => '',
                'id' => $prefix . 'gallery_subtitle',
                'type' => 'text'
            ), 
        )
    );

    



// End Code
    return $meta_boxes;
});
}
