<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }


    // This is your option name where all the Redux data is stored.
    $opt_name = "redux_demo";

    // This line is only for altering the demo. Can be easily removed.
    $opt_name = apply_filters( 'redux_demo/opt_name', $opt_name );

    /*
     *
     * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
     *
     */

    $sampleHTML = '';
    if ( file_exists( dirname( __FILE__ ) . '/info-html.html' ) ) {
        Redux_Functions::initWpFilesystem();

        global $wp_filesystem;

        $sampleHTML = $wp_filesystem->get_contents( dirname( __FILE__ ) . '/info-html.html' );
    }

    // Background Patterns Reader
    $sample_patterns_path = ReduxFramework::$_dir . '../sample/patterns/';
    $sample_patterns_url  = ReduxFramework::$_url . '../sample/patterns/';
    $sample_patterns      = array();
    
    if ( is_dir( $sample_patterns_path ) ) {

        if ( $sample_patterns_dir = opendir( $sample_patterns_path ) ) {
            $sample_patterns = array();

            while ( ( $sample_patterns_file = readdir( $sample_patterns_dir ) ) !== false ) {

                if ( stristr( $sample_patterns_file, '.png' ) !== false || stristr( $sample_patterns_file, '.jpg' ) !== false ) {
                    $name              = explode( '.', $sample_patterns_file );
                    $name              = str_replace( '.' . end( $name ), '', $sample_patterns_file );
                    $sample_patterns[] = array(
                        'alt' => $name,
                        'img' => $sample_patterns_url . $sample_patterns_file
                    );
                }
            }
        }
    }

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => __( 'Anondho Options', 'redux-framework-demo' ),
        'page_title'           => __( 'Anondho Options', 'redux-framework-demo' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => '',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => false,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => true,
        // Show the time the page took to load, etc
        'update_notice'        => true,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => 'redux_demo',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'use_cdn'              => true,
        // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'red',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    // ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
    $args['admin_bar_links'][] = array(
        'id'    => 'redux-docs',
        'href'  => 'http://docs.reduxframework.com/',
        'title' => __( 'Documentation', 'redux-framework-demo' ),
    );

    $args['admin_bar_links'][] = array(
        //'id'    => 'redux-support',
        'href'  => 'https://github.com/ReduxFramework/redux-framework/issues',
        'title' => __( 'Support', 'redux-framework-demo' ),
    );

    $args['admin_bar_links'][] = array(
        'id'    => 'redux-extensions',
        'href'  => 'reduxframework.com/extensions',
        'title' => __( 'Extensions', 'redux-framework-demo' ),
    );

    // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
    $args['share_icons'][] = array(
        'url'   => 'https://github.com/ReduxFramework/ReduxFramework',
        'title' => 'Visit us on GitHub',
        'icon'  => 'el el-github'
        //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
    );
    $args['share_icons'][] = array(
        'url'   => 'https://www.facebook.com/pages/Redux-Framework/243141545850368',
        'title' => 'Like us on Facebook',
        'icon'  => 'el el-facebook'
    );
    $args['share_icons'][] = array(
        'url'   => 'http://twitter.com/reduxframework',
        'title' => 'Follow us on Twitter',
        'icon'  => 'el el-twitter'
    );
    $args['share_icons'][] = array(
        'url'   => 'http://www.linkedin.com/company/redux-framework',
        'title' => 'Find us on LinkedIn',
        'icon'  => 'el el-linkedin'
    );

    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['opt_name'] );
        }
        $args['intro_text'] = sprintf( __( '<p>Did you know that Redux sets a global variable for you? To access any of your saved options from within your code you can use your global variable: <strong>$%1$s</strong></p>', 'redux-framework-demo' ), $v );
    } else {
        $args['intro_text'] = __( '<p>This text is displayed above the options panel. It isn\'t required, but more info is always better! The intro_text field accepts all HTML.</p>', 'redux-framework-demo' );
    }

    // Add content after the form.
    $args['footer_text'] = __( '', 'redux-framework-demo' );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => __( 'Theme Information 1', 'redux-framework-demo' ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => __( 'Theme Information 2', 'redux-framework-demo' ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo' )
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = __( '<p>This is the sidebar content, HTML is allowed.</p>', 'redux-framework-demo' );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */

    // -> START Basic Fields
    // Open Code






        Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-cogs',
                'title' => __('General Settings', 'anondho'),
                'fields' => array(                  
                    array(
                        'id' => 'author_content',
                        'type' => 'textarea',
                        'title' => __('Author content', 'anondho'),
                        'subtitle' => __('Author content', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Vergatheme'
                    ),
                    array(
                        'id' => 'description_content',
                        'type' => 'textarea',
                        'title' => __('Description content', 'anondho'),
                        'subtitle' => __('Description content', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Decent Material CV'
                    ),
                    array(
                        'id' => 'keywords_content',
                        'type' => 'textarea',
                        'title' => __('SEO Description', 'anondho'),
                        'subtitle' => __('SEO Description', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => ' '
                    ),
                    array(
                        'id' => 'viewport_content',
                        'type' => 'textarea',
                        'title' => __('Viewport content', 'anondho'),
                        'subtitle' => __('Viewport content', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'width=device-width, initial-scale=1'
                    ),
                    array(
                        'id' => 'seo_des',
                        'type' => 'textarea',
                        'title' => __('SEO Description', 'anondho'),
                        'subtitle' => __('SEO Description', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'seo_key',
                        'type' => 'textarea',
                        'title' => __('SEO Keywords', 'anondho'),
                        'subtitle' => __('SEO Keywords', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => ''
                    ), 
                )
            ));
            
            Redux::setSection( $opt_name, array(
                'icon' => ' el-icon-picture',
                'title' => __('Logo & Favicon Settings', 'anondho'),
                'fields' => array(       
                    array(
                        'id' => 'logo',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Logo Upload', 'anondho'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'anondho'),
                        'subtitle' => __('Upload your logo.', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'text_logo',
                        'type' => 'text',
                        'title' => __('Text Logo', 'anondho'),
                        'subtitle' => __('Input Text Logo', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'anondho'
                    ),
                    array(
                        'id' => 'favicon',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Favicon Upload', 'anondho'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'anondho'),
                        'subtitle' => __('Upload your Favicon.', 'anondho'),
                        'default' => ''
                    ),
                )
            ));



            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-list',
                'title' => __('Blog Settings', 'anondho'),
                'fields' => array(
                    array(
                        'id' => 'blog_image',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Blog Image', 'anondho'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'anondho'),
                        'subtitle' => __('Upload your Image Background', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'blog_title',
                        'type' => 'text',
                        'title' => __('Blog title', 'anondho'),
                        'subtitle' => __('Input Blog title', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Blog Title'
                    ),
                    array(
                        'id' => 'blog_subtitle',
                        'type' => 'textarea',
                        'title' => __('Blog Subtitle', 'anondho'),
                        'subtitle' => __('Input Blog Subtitle', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Blog Subtitle'
                    ),
                    array(
                        'id' => 'blog_details_title',
                        'type' => 'text',
                        'title' => __('Blog Details title', 'anondho'),
                        'subtitle' => __('Input Blog Details title', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Blog Details Title'
                    ),
                    array(
                        'id' => 'blog_details_subtitle',
                        'type' => 'textarea',
                        'title' => __('Blog Details subtitle', 'anondho'),
                        'subtitle' => __('Input Blog Details subtitle', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Blog subtitle'
                    ),
                    array(
                        'id' => 'blog_by',
                        'type' => 'text',
                        'title' => __('Text By', 'anondho'),
                        'subtitle' => __('Input Text By', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'By'
                    ), 
                    array(
                        'id' => 'blog_on',
                        'type' => 'text',
                        'title' => __('Text On', 'anondho'),
                        'subtitle' => __('Input Text On', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'On'
                    ), 
                    array(
                        'id' => 'blog_in',
                        'type' => 'text',
                        'title' => __('Text In', 'anondho'),
                        'subtitle' => __('Input Text In', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'In'
                    ), 
                    array(
                        'id' => 'blog_excerpt',
                        'type' => 'text',
                        'title' => __('Blog custom excerpt leng', 'anondho'),
                        'subtitle' => __('Input Blog custom excerpt leng', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => '50'
                    ),
                    array(
                        'id' => 'read_more',
                        'type' => 'text',
                        'title' => __('Button Text For Post', 'anondho'),
                        'subtitle' => __('Input Button Text', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Read More'
                    ),
                 )
            )); 



            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-list',
                'title' => __('Shop Settings', 'anondho'),
                'fields' => array(
                    array(
                        'id' => 'product_image',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Product Image', 'anondho'),
                        'compiler' => 'true',
                                    //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'anondho'),
                        'subtitle' => __('Upload your Product Image Background', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'product_title',
                        'type' => 'text',
                        'title' => __('Product title', 'anondho'),
                        'subtitle' => __('Input Product title', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Product Title'
                    ),
                    array(
                        'id' => 'product_subtitle',
                        'type' => 'text',
                        'title' => __('Product Subtitle', 'anondho'),
                        'subtitle' => __('Input Product Subtitle', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Product Subtitle'
                    ),
                    array(
                        'id' => 'cart_title',
                        'type' => 'text',
                        'title' => __('Cart title', 'anondho'),
                        'subtitle' => __('Input Cart title', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Cart'
                    ),
                    array(
                        'id' => 'cart_subtitle',
                        'type' => 'text',
                        'title' => __('Cart Subtitle', 'anondho'),
                        'subtitle' => __('Input Cart Subtitle', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Cart'
                    ),
                    array(
                        'id' => 'checkout_title',
                        'type' => 'text',
                        'title' => __('Checkout title', 'anondho'),
                        'subtitle' => __('Input Checkout title', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Checkout'
                    ),
                    array(
                        'id' => 'checkout_subtitle',
                        'type' => 'text',
                        'title' => __('Checkout Subtitle', 'anondho'),
                        'subtitle' => __('Input Checkout Subtitle', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Checkout'
                    ),
                    array(
                        'id' => 'login_title',
                        'type' => 'text',
                        'title' => __('Login title', 'anondho'),
                        'subtitle' => __('Input Login title', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Login'
                    ),
                    array(
                        'id' => 'login_subtitle',
                        'type' => 'text',
                        'title' => __('Login Subtitle', 'anondho'),
                        'subtitle' => __('Input Login Subtitle', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Login'
                    ),
                    array(
                        'id' => 'reset_title',
                        'type' => 'text',
                        'title' => __('Lost Password title', 'anondho'),
                        'subtitle' => __('Input Lost Password title', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Lost Password'
                    ),
                    array(
                        'id' => 'reset_subtitle',
                        'type' => 'text',
                        'title' => __('Lost Password Subtitle', 'anondho'),
                        'subtitle' => __('Input Lost Password Subtitle', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Lost Password'
                    ),
                    array(
                        'id' => 'product_details_title',
                        'type' => 'text',
                        'title' => __('Product Details title', 'anondho'),
                        'subtitle' => __('Input Product Details title', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Product Details Title'
                    ),
                    array(
                        'id' => 'product_details_subtitle',
                        'type' => 'text',
                        'title' => __('Product Details Subtitle', 'anondho'),
                        'subtitle' => __('Input Product Details Subtitle', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Product Details Subtitle'
                    ),
                    array(
                        'id' => 'register_link',
                        'type' => 'text',
                        'title' => __('Register Link', 'anondho'),
                        'subtitle' => __('Input Register Link', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => '#'
                    ),
                )
            )); 
            
 

            

            Redux::setSection( $opt_name, array(
                'icon' => ' el-icon-picture',
                'title' => __('Page Settings', 'anondho'),
                'fields' => array(       
                    array(
                        'id' => 'page_image',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Page Image', 'anondho'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'anondho'),
                        'subtitle' => __('Upload your Background Image on Page Default.', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'page_subtitle',
                        'type' => 'text',
                        'title' => __('Page subtitle', 'anondho'),
                        'subtitle' => __('Input Page subtitle', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do.'
                    ),
                    array(
                        'id' => 'book_ticket',
                        'type' => 'text',
                        'title' => __('Button Text For Page', 'anondho'),
                        'subtitle' => __('Input Button Text', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Book Ticket'
                    ),
                    array(
                        'id' => 'event_details_title',
                        'type' => 'text',
                        'title' => __('Event Details title', 'anondho'),
                        'subtitle' => __('Input Event Details title', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Event Details'
                    ),
                )
            ));
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-graph',
                'title' => __('404 Settings', 'anondho'),
                'fields' => array(
                    array(
                        'id' => '404_image',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('404 Image', 'anondho'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'anondho'),
                        'subtitle' => __('Upload your Image Background', 'anondho'),
                        'default' => ''
                    ),
                     array(
                        'id' => '404_title',
                        'type' => 'text',
                        'title' => __('404 Title', 'anondho'),
                        'subtitle' => __('Input 404 Title', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => '404 Error'
                    ),  
                    array(
                        'id' => '404_subtitle',
                        'type' => 'textarea',
                        'title' => __('404 subtitle', 'anondho'),
                        'subtitle' => __('Input 404 subtitle', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Page Not Found..'
                    ), 
                    array(
                        'id' => '404_desc',
                        'type' => 'textarea',
                        'title' => __('404 description', 'anondho'),
                        'subtitle' => __('Input 404 description', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Lorem ipsum dolor sit amet, consectetur adipisicing elit. Repudiandae odit iste exerc ssumenda voluptas quidem sit maiores odio velit voluptate.'
                    ), 
                    array(
                        'id' => '404_text',
                        'type' => 'text',
                        'title' => __('404 Text Button', 'anondho'),
                        'subtitle' => __('Input 404 Button', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Back To Home page'
                    ), 
                               
                 )
            ));

            Redux::setSection( $opt_name, array(
                'icon' => ' el-icon-credit-card',
                'title' => __('Header Settings', 'anondho'),
                'fields' => array(  
                    array(
                        'id' => 'header_logo',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Header Logo', 'anondho'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'anondho'),
                        'subtitle' => __('Upload your Logo Image on Page Default.', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'header_logo_2',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Header Logo 2', 'anondho'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'anondho'),
                        'subtitle' => __('Upload your Logo Image 2 on Page Default.', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'header_logo_3',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Header Logo 3', 'anondho'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'anondho'),
                        'subtitle' => __('Upload your Logo Image 3 on Page Default.', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'header_link_facebook',
                        'type' => 'text',
                        'title' => __('Link Facebook', 'anondho'),
                        'subtitle' => __('Input Link Facebook', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'header_link_twitter',
                        'type' => 'text',
                        'title' => __('Link Twitter', 'anondho'),
                        'subtitle' => __('Input Link Twitter', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'header_link_instagram',
                        'type' => 'text',
                        'title' => __('Link Instagram', 'anondho'),
                        'subtitle' => __('Input Link Instagram', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => '#'
                    ), 
                    array(
                        'id' => 'header_link_youtube',
                        'type' => 'text',
                        'title' => __('Link Youtube', 'anondho'),
                        'subtitle' => __('Input Link Youtube', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'header_link_google',
                        'type' => 'text',
                        'title' => __('Link Google', 'anondho'),
                        'subtitle' => __('Input Link Google', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => '#'
                    ),
                    array(
                        'id' => 'header_lang_1',
                        'type' => 'text',
                        'title' => __('Header Language 1', 'anondho'),
                        'subtitle' => __('Input Header Language 1', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'header_lang_2',
                        'type' => 'text',
                        'title' => __('Header Language 2', 'anondho'),
                        'subtitle' => __('Input Header Language 2', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'header_lang_3',
                        'type' => 'text',
                        'title' => __('Header Language 3', 'anondho'),
                        'subtitle' => __('Input Header Language 3', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'header_lang_4',
                        'type' => 'text',
                        'title' => __('Header Language 4', 'anondho'),
                        'subtitle' => __('Input Header Language 4', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'link_lang_1',
                        'type' => 'text',
                        'title' => __('link Language 1', 'anondho'),
                        'subtitle' => __('Input link Language 1', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'link_lang_2',
                        'type' => 'text',
                        'title' => __('link Language 2', 'anondho'),
                        'subtitle' => __('Input link Language 2', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'link_lang_3',
                        'type' => 'text',
                        'title' => __('link Language 3', 'anondho'),
                        'subtitle' => __('Input link Language 3', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'link_lang_4',
                        'type' => 'text',
                        'title' => __('link Language 4', 'anondho'),
                        'subtitle' => __('Input link Language 4', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'header_address_title',
                        'type' => 'text',
                        'title' => __('Header Address Title', 'anondho'),
                        'subtitle' => __('Input Header Address Title', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'About Us'
                    ),
                    array(
                        'id' => 'header_address_subtitle',
                        'type' => 'text',
                        'title' => __('Header Address Subtitle', 'anondho'),
                        'subtitle' => __('Input Header Address Subtitle', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => '123/A, Miranda City Likaoli  Prikano, Dope United States '
                    ),
                    array(
                        'id' => 'header_phone_title',
                        'type' => 'text',
                        'title' => __('Header Phone Title', 'anondho'),
                        'subtitle' => __('Input Header Phone Title', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Contact Info'
                    ),
                    array(
                        'id' => 'header_phone_subtitle_1',
                        'type' => 'text',
                        'title' => __('Header Phone Subtitle 1', 'anondho'),
                        'subtitle' => __('Input Header Phone Subtitle 1', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => '+0989 7876 9865 9'
                    ),
                    array(
                        'id' => 'header_phone_subtitle_2',
                        'type' => 'text',
                        'title' => __('Header Phone Subtitle 2', 'anondho'),
                        'subtitle' => __('Input Header Phone Subtitle 2', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => '+(090) 8765 86543 85'
                    ),
                    array(
                        'id' => 'header_email_title',
                        'type' => 'text',
                        'title' => __('Header Email Title', 'anondho'),
                        'subtitle' => __('Input Header Email Title', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Email Address'
                    ),
                    array(
                        'id' => 'header_email_subtitle_1',
                        'type' => 'text',
                        'title' => __('Header Email Subtitle 1', 'anondho'),
                        'subtitle' => __('Input Header Email Subtitle 1', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'info@example.com'
                    ),
                    array(
                        'id' => 'header_email_subtitle_2',
                        'type' => 'text',
                        'title' => __('Header Email Subtitle 2', 'anondho'),
                        'subtitle' => __('Input Header Email Subtitle 2', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'example.mail@hum.com'
                    ),
                    array(
                        'id' => 'header_image_1',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Header Image 1', 'anondho'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'anondho'),
                        'subtitle' => __('Upload your header Image 1', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'header_image_2',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Header Image 2', 'anondho'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'anondho'),
                        'subtitle' => __('Upload your header Image 2', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'header_image_3',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Header Image 3', 'anondho'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'anondho'),
                        'subtitle' => __('Upload your header Image 3', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'header_image_4',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Header Image 4', 'anondho'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'anondho'),
                        'subtitle' => __('Upload your header Image 4', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'header_image_5',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Header Image 5', 'anondho'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'anondho'),
                        'subtitle' => __('Upload your header Image 5', 'anondho'),
                        'default' => ''
                    ),
                    array(
                        'id' => 'header_image_6',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Header Image 6', 'anondho'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'anondho'),
                        'subtitle' => __('Upload your header Image 6', 'anondho'),
                        'default' => ''
                    ),
                )
            ));



            Redux::setSection( $opt_name, array(
                'icon' => ' el-icon-credit-card',
                'title' => __('Header 2, 3 Settings', 'anondho'),
                'fields' => array(  
                    array(
                        'id' => 'header_welcome',
                        'type' => 'text',
                        'title' => __('Header Welcome', 'anondho'),
                        'subtitle' => __('Input Header Welcome', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Welcome to Anondho.'
                    ),
                    array(
                        'id' => 'header_help',
                        'type' => 'text',
                        'title' => __('Header Help', 'anondho'),
                        'subtitle' => __('Input Header Help', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Needs Help?'
                    ),
                    array(
                        'id' => 'header_link_help',
                        'type' => 'text',
                        'title' => __('Header Link Help', 'anondho'),
                        'subtitle' => __('Input Header Link Help', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'http://shtheme.info/demosd/anondho/?page_id=334'
                    ),
                    array(
                        'id' => 'header_phone',
                        'type' => 'text',
                        'title' => __('Header Phone', 'anondho'),
                        'subtitle' => __('Input Header Phone', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => '+80234569870'
                    ),
                    array(
                        'id' => 'header_adress',
                        'type' => 'text',
                        'title' => __('Header Adress', 'anondho'),
                        'subtitle' => __('Input Header Adress', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => '507, Modern Street, USA'
                    ),
                    array(
                        'id' => 'header_time',
                        'type' => 'text',
                        'title' => __('Header Time', 'anondho'),
                        'subtitle' => __('Input Header Time', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'Mon - Fry : 10 am - 6 pm'
                    ),
                )
            ));


            
            Redux::setSection( $opt_name, array(
                'icon' => ' el-icon-credit-card',
                'title' => __('Footer Settings', 'anondho'),
                'fields' => array( 
                    array(
                        'id' => 'footer_desc',
                        'type' => 'text',
                        'title' => __('Footer Description', 'anondho'),
                        'subtitle' => __('Footer Description', 'anondho'),
                        'default' => 'Subscribe to our email newsletter to get update, discount and special offers.',
                    ),
                    array(
                        'id' => 'footer_image',
                        'type' => 'media',
                        'url' => true,
                        'title' => __('Footer Image', 'anondho'),
                        'compiler' => 'true',
                        //'mode' => false, // Can be set to false to allow any media type, or can also be set to any mime type.
                        'desc' => __('', 'anondho'),
                        'subtitle' => __('Upload your Footer Image', 'anondho'),
                        'default' => ''
                    ),  
                    array(
                        'id' => 'footer_text',
                        'type' => 'text',
                        'title' => __('Footer Text', 'anondho'),
                        'subtitle' => __('Copyright Text', 'anondho'),
                        'default' => 'COPYRIGHT  2023.Shtheme. ALL RIGHTS RESERVED',
                    ),
                    array(
                        'id' => 'footer_text_2',
                        'type' => 'text',
                        'title' => __('Footer Text 2', 'anondho'),
                        'subtitle' => __('Footer Text 2', 'anondho'),
                        'default' => 'Purchase our Template',
                    ),
                    array(
                        'id' => 'footer_link',
                        'type' => 'text',
                        'title' => __('Footer Link', 'anondho'),
                        'subtitle' => __('Footer Link', 'anondho'),
                        'default' => '#',
                    ),
                )
            ));
            
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-graph',
                'title' => __('Form Settings', 'anondho'),
                'fields' => array(
                     array(
                        'id' => 'form_email',
                        'type' => 'text',
                        'title' => __('Form email', 'anondho'),
                        'subtitle' => __('Form email', 'anondho'),
                        'desc' => __('', 'anondho'),
                        'default' => 'info@domain.com'
                    ),                 
                 )
            ));
            Redux::setSection( $opt_name, array(
                'icon' => 'el-icon-website',
                'title' => __('Styling Options', 'anondho'),
                'fields' => array(
                    array(
                        'id' => 'chosen-color',
                        'type' => 'checkbox',
                        'title' => __('Enable edit color', 'anondho'),
                        'subtitle' => '',
                        'desc' => '',
                        'default' => '0'// 1 = on | 0 = off
                    ),
                    array(
                        'id' => 'main-color-1',
                        'type' => 'color',
                        'title' => __('Theme Main Color 1', 'anondho'),
                        'subtitle' => __('Pick the main color for the theme (default: #ffe79b).', 'anondho'),
                        'default' => '#2c3e50',
                        'validate' => 'color',
                    ),
                )
            ));




            


            


            





            

    
    // End Code
    

    if ( file_exists( dirname( __FILE__ ) . '/../README.md' ) ) {
        $section = array(
            'icon'   => 'el el-list-alt',
            'title'  => __( 'Documentation', 'redux-framework-demo' ),
            'fields' => array(
                array(
                    'id'       => '17',
                    'type'     => 'raw',
                    'markdown' => true,
                    'content_path' => dirname( __FILE__ ) . '/../README.md', // FULL PATH, not relative please
                    //'content' => 'Raw content here',
                ),
            ),
        );
        Redux::setSection( $opt_name, $section );
    }
    /*
     * <--- END SECTIONS
     */


    /*
     *
     * YOU MUST PREFIX THE FUNCTIONS BELOW AND ACTION FUNCTION CALLS OR ANY OTHER CONFIG MAY OVERRIDE YOUR CODE.
     *
     */

    /*
    *
    * --> Action hook examples
    *
    */

    // If Redux is running as a plugin, this will remove the demo notice and links
    //add_action( 'redux/loaded', 'remove_demo' );

    // Function to test the compiler hook and demo CSS output.
    // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
    //add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);

    // Change the arguments after they've been declared, but before the panel is created
    //add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );

    // Change the default value of a field after it's been set, but before it's been useds
    //add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );

    // Dynamically add a section. Can be also used to modify sections/fields
    //add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');

    /**
     * This is a test function that will let you see when the compiler hook occurs.
     * It only runs if a field    set with compiler=>true is changed.
     * */
    if ( ! function_exists( 'compiler_action' ) ) {
        function compiler_action( $options, $css, $changed_values ) {
            echo '<h1>The compiler hook has run!</h1>';
            echo "<pre>";
            print_r( $changed_values ); // Values that have changed since the last save
            echo "</pre>";
            //print_r($options); //Option values
            //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )
        }
    }

    /**
     * Custom function for the callback validation referenced above
     * */
    if ( ! function_exists( 'redux_validate_callback_function' ) ) {
        function redux_validate_callback_function( $field, $value, $existing_value ) {
            $error   = false;
            $warning = false;

            //do your validation
            if ( $value == 1 ) {
                $error = true;
                $value = $existing_value;
            } elseif ( $value == 2 ) {
                $warning = true;
                $value   = $existing_value;
            }

            $return['value'] = $value;

            if ( $error == true ) {
                $field['msg']    = 'your custom error message';
                $return['error'] = $field;
            }

            if ( $warning == true ) {
                $field['msg']      = 'your custom warning message';
                $return['warning'] = $field;
            }

            return $return;
        }
    }

    /**
     * Custom function for the callback referenced above
     */
    if ( ! function_exists( 'redux_my_custom_field' ) ) {
        function redux_my_custom_field( $field, $value ) {
            print_r( $field );
            echo '<br/>';
            print_r( $value );
        }
    }

    /**
     * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
     * Simply include this function in the child themes functions.php file.
     * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
     * so you must use get_template_directory_uri() if you want to use any of the built in icons
     * */
    if ( ! function_exists( 'dynamic_section' ) ) {
        function dynamic_section( $sections ) {
            //$sections = array();
            $sections[] = array(
                'title'  => __( 'Section via hook', 'redux-framework-demo' ),
                'desc'   => __( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'redux-framework-demo' ),
                'icon'   => 'el el-paper-clip',
                // Leave this as a blank section, no options just some intro text set above.
                'fields' => array()
            );

            return $sections;
        }
    }

    /**
     * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
     * */
    if ( ! function_exists( 'change_arguments' ) ) {
        function change_arguments( $args ) {
            //$args['dev_mode'] = true;

            return $args;
        }
    }

    /**
     * Filter hook for filtering the default value of any given field. Very useful in development mode.
     * */
    if ( ! function_exists( 'change_defaults' ) ) {
        function change_defaults( $defaults ) {
            $defaults['str_replace'] = 'Testing filter hook!';

            return $defaults;
        }
    }

    /**
     * Removes the demo link and the notice of integrated demo from the redux-framework plugin
     */
    if ( ! function_exists( 'remove_demo' ) ) {
        function remove_demo() {
            // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
            if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
                remove_filter( 'plugin_row_meta', array(
                    ReduxFrameworkPlugin::instance(),
                    'plugin_metalinks'
                ), null, 2 );

                // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
                remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
            }
        }
    }

