<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsAbout extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-about';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'About', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'about' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_features',
			[
				'label' => esc_html__( 'About', 'bdevs-elementor' ),
			]	
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'about-style-1'  => esc_html__( 'About Home 1', 'bdevs-elementor' ),
					'about-style-2' => esc_html__( 'About Home 2', 'bdevs-elementor' ),
					'about-style-3' => esc_html__( 'About With Video', 'bdevs-elementor' ),
					'about-style-4' => esc_html__( 'About With BG', 'bdevs-elementor' ),
				],
				'default'   => 'about-style-1',
			]
		);


		$this->add_control(
			'image',
			[
				'label'   => esc_html__( 'About Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your About Image', 'bdevs-elementor' ),
				'condition' => [
					'chose_style' => ['about-style-1']
				],
			]
		);

		$this->add_control(
			'sub_heading',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is sub heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		$this->add_control(
			'desc',
			[
				'label'       => __( 'Description', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your description', 'bdevs-elementor' ),
				'default'     => __( 'It is content', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'link',
			[
				'label'       => __( 'Link', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your link', 'bdevs-elementor' ),
				'default'     => __( 'It is link', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'text_btn',
			[
				'label'       => __( 'Text Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your button', 'bdevs-elementor' ),
				'default'     => __( 'It is button', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);


		$this->end_controls_section();

		/** facts section **/
		$this->start_controls_section(
			'home2_section',
			[
				'label' => esc_html__( 'About Home 2', 'bdevs-elementor' ),
				'condition' => [
					'chose_style' => ['about-style-2','about-style-3']
				],
			]
		);

		$this->add_control(
			'image_home_2',
			[
				'label'   => esc_html__( 'About Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your About Image', 'bdevs-elementor' ),
				
			]
		);

		$this->add_control(
			'image_1_home_2',
			[
				'label'   => esc_html__( 'About Image 1', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your About Image 1', 'bdevs-elementor' ),
				
			]
		);

		$this->add_control(
			'image_2_home_2',
			[
				'label'   => esc_html__( 'About Image 2', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your About Image 2', 'bdevs-elementor' ),
				
			]
		);

			


		$this->add_control(
			'heading_home_2',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		$this->add_control(
			'sub_heading_home_2',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is sub heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		
		$this->add_control(
			'content_home_2',
			[
				'label'       => __( 'Content', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your content', 'bdevs-elementor' ),
				'default'     => __( 'It is content', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'video_link_home_2',
			[
				'label'       => __( 'Video Link', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your video link', 'bdevs-elementor' ),
				'default'     => __( 'It is video link', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'button_home_2',
			[
				'label'       => __( 'Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your button', 'bdevs-elementor' ),
				'default'     => __( 'It is Button', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		

		$this->end_controls_section();


		/** 
		*	content list section 
		**/
		$this->start_controls_section(
			'content_lists_section',
			[
				'label' => esc_html__( 'Lists', 'bdevs-elementor' ),
				'condition' => [
					'chose_style' => ['about-style-2','about-style-4']
				],
			]
		);

		$this->add_control(
			'tab_lists',
			[
				'label' => esc_html__( 'List Item', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'List #1', 'bdevs-elementor' ),
					]
				],
				'fields' => [										
					[
						'name'        => 'title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => __( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do.', 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();



		/** 
		*	Author section 
		**/
		$this->start_controls_section(
			'section_content_author',
			[
				'label' => esc_html__( 'Author Info', 'bdevs-elementor' ),
				'condition' => [
					'chose_style' => ['about-style-1']
				],
			]
		);
		$this->add_control(
			'image_author',
			[
				'label'   => esc_html__( 'Author Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Groth Image', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		$this->add_control(
			'author_heading',
			[
				'label'       => __( 'Author Name', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Author Name', 'bdevs-elementor' ),
				'default'     => __( 'Rosalina D. Williamson', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'author_designation',
			[
				'label'       => __( 'Author Name', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Author Designation', 'bdevs-elementor' ),
				'default'     => __( 'Founder', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		$this->end_controls_section();		

		/** 
		*	Video section 
		**/
		$this->start_controls_section(
			'video_section',
			[
				'label' => esc_html__( 'Video Section', 'bdevs-elementor' ),
				'condition' => [
					'chose_style' => ['about-style-3']
				],
			]
		);
		$this->add_control(
			'preview_image',
			[
				'label'   => esc_html__( 'Preview Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Preview Image', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		$this->add_control(
			'video_link',
			[
				'label'       => __( 'Video Link', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter vidoe link', 'bdevs-elementor' ),
				'default'     => __( 'https://www.youtube.com/watch?v=I3u3lFA9GX4', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->end_controls_section();		



		/** 
		*	Link section 
		**/
		$this->start_controls_section(
			'link_section_content',
			[
				'label' => esc_html__( 'Link Info', 'bdevs-elementor' ),
				'condition' => [
					'chose_style' => ['about-style-2','about-style-4']
				],
			]
		);		

		$this->add_control(
			'link_text',
			[
				'label'       => __( 'Link Text', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Type Link Text Here...', 'bdevs-elementor' ),
				'default'     => __( 'Learn More', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'link',
			[
				'label' => __( 'Link', 'plugin-domain' ),
				'type' => \Elementor\Controls_Manager::URL,
				'placeholder' => __( 'https://your-link.com', 'plugin-domain' ),
				'show_external' => true,
				'default' => [
					'url' => '',
					'is_external' => true,
					'nofollow' => true,
				],
			]
		);
	

		$this->end_controls_section();


		/** 
		*	Layout section 
		**/
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			

		$this->add_control(
			'show_sub_title',
			[
				'label'   => esc_html__( 'Show Sub Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->add_control(
			'show_content',
			[
				'label'   => esc_html__( 'Show Content', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		$chose_style = $settings['chose_style'];
		extract($settings);
		
		if( $chose_style == 'about-style-1' ): ?>
        <div class="about-area fix pt-110">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-6 col-lg-6">
                            <div class="about-wrapper">
                                <div class="about-text">
                                	<?php if (( '' !== $sub_heading ) && ( $show_sub_title )) : ?>
                                    <h1><?php echo wp_kses_post( $sub_heading ); ?></h1>
                                    <?php endif; ?>
                                    <?php if (( '' !== $heading ) && ( $show_title )) : ?>
                                    <h2><?php echo wp_kses_post( $heading ); ?></h2>
                                    <?php endif; ?>
                                    <?php if ( '' !== $desc ): ?>
                                    <?php echo wp_kses_post( $desc ); ?>
                                    <?php endif; ?>
									<?php if (( '' !== $link) && ('' !== $text_btn)): ?>
                                    <a class="btn" href="<?php echo wp_kses_post( $link ); ?>"><span class="btn-text"><?php echo wp_kses_post( $text_btn ); ?></span><span class="btn-border"></span></a>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                        <div class="col-xl-6 col-lg-6">
                        	<?php if ( '' !== $image )  : ?>
                            <div class="about-img">
                                <img src="<?php echo wp_kses_post($settings['image']['url']); ?>" alt="">
                            </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
		<?php elseif( $chose_style == 'about-style-2' ): ?>
			<div class="about-area  pt-130 pb-100">
				<div class="container">
					<div class="row">
						<div class="col-xl-7 col-lg-6">
							<div class="single-about mb-30">
								<?php if (( '' !== $settings['image_home_2']['url'] ) && ( $settings['show_image'] )): ?>
								<div class="about-2-img">
									<img src="<?php echo wp_kses_post($settings['image_home_2']['url']); ?>" alt="">
								</div>
								<?php endif; ?>		
								<div class="about-1-video">
									<div class="about-video text-right">
										<?php if (( '' !== $settings['button_home_2'] ) && ( $settings['show_button'] )): ?>
										<a  class="popup-video" href="<?php echo wp_kses_post($settings['video_link_home_2']); ?>"><i class="fas fa-play"></i></a> <span><?php echo wp_kses_post($settings['button_home_2']); ?></span>
										<?php endif; ?>		
									</div>
								</div>
							</div>
						</div>
						<div class="col-xl-5 col-lg-6">
							<div class="about-2-wrapper mb-30">
								<div class="about-content">
									<?php if (( '' !== $settings['heading_home_2'] ) && ( $settings['show_title'] )): ?>
									<h1><?php echo wp_kses_post($settings['heading_home_2']); ?> </h1>
									<?php endif; ?>		
									<?php if (( '' !== $settings['sub_heading_home_2'] ) && ( $settings['show_sub_title'] )): ?>
									<span><?php echo wp_kses_post($settings['sub_heading_home_2']); ?></span>
									<?php endif; ?>		
									<?php if (( '' !== $settings['content_home_2'] ) && ( $settings['show_content'] )): ?>
									<p><?php echo wp_kses_post($settings['content_home_2']); ?></p>
									<?php endif; ?>		
									<div class="about-us-img">
										<?php if ( '' !== $settings['image_1_home_2']['url'] ): ?>
										<div class="about-3-img f-left">
											<img src="<?php echo wp_kses_post($settings['image_1_home_2']['url']); ?>" alt="">
										</div>
										<?php endif; ?>		
										<?php if ( '' !== $settings['image_1_home_2']['url'] ): ?>
										<div class="about-4-img">
											<img src="<?php echo wp_kses_post($settings['image_2_home_2']['url']); ?>" alt="">
										</div>
										<?php endif; ?>
									</div>
								</div>
							</div>

						</div>
					</div>
				</div>
			</div>
        
		<?php endif; ?>	
	<?php
	}

}