<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsBlog extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-blog';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Blog Area', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'blog' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_Blog',
			[
				'label' => esc_html__( 'Blog', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'blog_home_1'  => esc_html__( 'Blog Home 1', 'bdevs-elementor' ),
					'blog_home_2' => esc_html__( 'Blog Home 2', 'bdevs-elementor' ),
					'blog_home_3' => esc_html__( 'Blog Home 3', 'bdevs-elementor' ),
				],
				'default'   => 'blog_home_1',
			]
		);


		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_heading',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Sub Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	


		$this->add_control(
			'content',
			[
				'label'       => __( 'Content', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your content', 'bdevs-elementor' ),
				'default'     => __( 'It is Content', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'post_number',
			[
				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'2'  => esc_html__( '2', 'bdevs-elementor' ),
					'4' => esc_html__( '4', 'bdevs-elementor' ),
					'6' => esc_html__( '6', 'bdevs-elementor' ),
					'8' => esc_html__( '8', 'bdevs-elementor' ),
				],
				'default'   => '2',
			]
		);

		$this->add_control(
			'post_order',
			[
				'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
					'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
				],
				'default'   => 'desc',
			]
		);

		$this->add_control(
			'link',
			[
				'label'       => __( 'Link', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your link', 'bdevs-elementor' ),
				'default'     => __( 'It is Link', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'button',
			[
				'label'       => __( 'Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your button', 'bdevs-elementor' ),
				'default'     => __( 'It is Button', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	




		$this->end_controls_section();


		$this->start_controls_section(
			'section_content_blog_2',
			[
				'label' => esc_html__( 'Blog Home 2', 'bdevs-elementor' ),
				
			]
		);
		$this->add_control(
			'heading_2',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_heading_2',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Sub Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	


		$this->add_control(
			'post_number_2',
			[
				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'3'  => esc_html__( '3', 'bdevs-elementor' ),
					'6' => esc_html__( '6', 'bdevs-elementor' ),
					'9' => esc_html__( '9', 'bdevs-elementor' ),
					'12' => esc_html__( '12', 'bdevs-elementor' ),
				],
				'default'   => '3',
			]
		);

		$this->add_control(
			'post_order_2',
			[
				'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
					'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
				],
				'default'   => 'ASC',
			]
		);


		$this->end_controls_section();




		$this->start_controls_section(
			'section_content_blog_3',
			[
				'label' => esc_html__( 'Blog Home 3', 'bdevs-elementor' ),
				
			]
		);
		$this->add_control(
			'heading_3',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_heading_3',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Sub Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	


		$this->add_control(
			'post_number_3',
			[
				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'2'  => esc_html__( '2', 'bdevs-elementor' ),
					'4' => esc_html__( '4', 'bdevs-elementor' ),
					'6' => esc_html__( '6', 'bdevs-elementor' ),
					'8' => esc_html__( '8', 'bdevs-elementor' ),
				],
				'default'   => '2',
			]
		);

		$this->add_control(
			'post_order_3',
			[
				'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
					'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
				],
				'default'   => 'ASC',
			]
		);


		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->add_control(
			'show_content',
			[
				'label'   => esc_html__( 'Show Content', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

		

		$this->start_controls_section(
			'section_content_button',
			[
				'label'     => esc_html__( 'Button', 'bdevs-elementor' ),
				'condition' => [
					'show_button' => 'yes',
				],
			]
		);

		$this->add_control(
			'button_text',
			[
				'label'       => esc_html__( 'Button Text', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Read More', 'bdevs-elementor' ),
				'placeholder' => esc_html__( 'Read More', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'icon',
			[
				'label'       => esc_html__( 'Icon', 'bdevs-elementor' ),
				'type'        => Controls_Manager::ICON,
				'label_block' => true,
			]
		);

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		$chose_style = $settings['chose_style'];

		$order = $settings['post_order'];
		$post_number = $settings['post_number'];

		$post_number_2 = $settings['post_number_2'];
		$order_2 = $settings['post_order_2'];

		$post_number_3 = $settings['post_number_3'];
		$order_3 = $settings['post_order_3'];

		?>
		<?php if( $chose_style == 'blog_home_1' ): ?>
		<div class="news-area news-padding pt-130 pb-100">
            <div class="container-fluid container-padding">
                <div class="row">
                    <div class="col-xl-4 col-lg-4 col-md-6">
                        <div class="blog-title mb-30">
                            <span></span>
                            <?php if (( '' !== $settings['heading'] ) && ( $settings['show_title'] )): ?>
                                <h1><?php echo wp_kses_post($settings['heading']); ?></h1>
                            <?php endif; ?>	

                            <?php if (( '' !== $settings['sub_heading'] ) && ( $settings['show_content'] )): ?>
								<h2><?php echo wp_kses_post($settings['sub_heading']); ?></h2>
							<?php endif; ?>	

                            <?php if ( '' !== $settings['content'] ): ?>
								<p><?php echo wp_kses_post($settings['content']); ?></p>
							<?php endif; ?>	

							<?php if (( '' !== $settings['button'] )&& ( $settings['show_button'] )): ?>
                            <a class="btn" href="<?php echo wp_kses_post($settings['link']); ?>"><span class="btn-text"><?php echo wp_kses_post($settings['button']); ?></span> <span class="btn-border"></span></a>
                            <?php endif; ?>	
                        </div>
                    </div>
                    <?php 
                	$args = new \WP_Query(array(   
                		'post_type' => 'post', 
                		'posts_per_page'=> $post_number,
	                    'order'         => $order,
                	));  
                	if($args->have_posts()):
                	while ($args -> have_posts()) : $args -> the_post(); 

                		$home_title = get_post_meta(get_the_ID(),'_cmb_home_title', true); 
                		$home_image = get_post_meta(get_the_ID(),'_cmb_home_image', true); 
                		?>
                    <div class="col-xl-4 col-lg-4 col-md-6 col-sm-6 mb-30">
                        <div class="news-wrapper">
                            <div class="news-img">
                                <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($home_image);?>" alt=""></a>
                            </div>
                            <div class="news-text">
                                <h4><a href="<?php the_permalink();?>"><?php echo htmlspecialchars_decode(esc_attr($home_title));?></a></h4>
                                <div class="blog-meta">
                                    <span> <i class="far fa-user"></i> <?php the_author_posts_link(); ?> </span>
                                    <span> <i class="fal fa-calendar-alt"></i> <?php the_time(get_option( 'date_format'));?></span>
                                    <span> <i class="far fa-comments"></i> <?php comments_number( esc_html__('(0)', 'anondho'), 
                                  esc_html__('(01)', 'anondho'), esc_html__('(%)', 'anondho') ); ?></span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <?php 
                    endwhile;  
                    wp_reset_postdata();
                endif; 
                ?>
                </div>
            </div>
        </div>
        <?php elseif( $chose_style == 'blog_home_2' ): ?>
        	<div class="blog-area pb-90">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-8 col-lg-8 offset-lg-2 offset-xl-2">
                            <div class="area-title text-center pb-75">
                                <span></span>
                                <?php if (( '' !== $settings['heading_2'] ) && ( $settings['show_title'] )): ?>
                                <h1><?php echo wp_kses_post($settings['heading_2']); ?></h1>
                                <?php endif; ?>	
                                <?php if (( '' !== $settings['sub_heading_2'] ) && ( $settings['show_content'] )): ?>
                                <p><?php echo wp_kses_post($settings['sub_heading_2']); ?></p>
                                <?php endif; ?>	
                            </div>
                        </div>
                    </div>
                    <div class="row">
                    	<?php 
                    	$args = new \WP_Query(array(   
                    		'post_type' => 'post', 
                    		'posts_per_page'=> $post_number_2,
	                    	'order'         => $order_2,
                    	));  
                    	if($args->have_posts()):
                    		while ($args -> have_posts()) : $args -> the_post(); 
                    			$home_subtitle = get_post_meta(get_the_ID(),'_cmb_home_subtitle', true); 
                    			$home_title = get_post_meta(get_the_ID(),'_cmb_home_title', true); 
                    			$home_image = get_post_meta(get_the_ID(),'_cmb_home_image', true); 
                    			?>
                        <div class="col-xl-4 col-lg-4 col-md-6">
                            <div class="blog-wrapper mb-30">
                                <div class="blog-img">
                                    <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($home_image);?>" alt=""></a>
                                </div>
                                <div class="blog-text">
									<div class="post-meta mb-15">
										<span>
											<a href="<?php print esc_url(get_author_posts_url(get_the_author_meta('ID'))); ?>">
												<i class="far fa-user"></i> <?php print get_the_author(); ?>
											</a>
										</span>
										<span><i class="far fa-calendar-check"></i> <?php the_time(get_option('date_format')); ?> </span>
									</div>
                                    <h3><a href="<?php the_permalink();?>"><?php echo htmlspecialchars_decode(esc_attr($home_title));?></a></h3>
                                    <p><?php print wp_trim_words(get_the_content(), 23, ''); ?></p>
									<div class="lb-more"><a href="<?php the_permalink();?>">Read More <i class="far fa-angle-double-right"></i></a></div>
                                </div>
                            </div>
                        </div>
                        <?php 
                    endwhile;  
                    wp_reset_postdata();
                endif; 
                ?>
                    </div>
                </div>
            </div>
        <?php elseif( $chose_style == 'blog_home_3' ): ?>
        	<div class="blog-area pt-120 pb-100 dark-soft">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-8 col-lg-8 offset-lg-2 offset-xl-2">
                            <div class="area-title-light text-center pb-75">
                            	<?php if (( '' !== $settings['heading_3'] ) && ( $settings['show_title'] )): ?>
                                <h1><?php echo wp_kses_post($settings['heading_3']); ?></h1>
                                <?php endif; ?>	
                                <?php if (( '' !== $settings['sub_heading_3'] ) && ( $settings['show_content'] )): ?>
                                <p><?php echo wp_kses_post($settings['sub_heading_3']); ?></p>
                                <?php endif; ?>	
                            </div>
                        </div>
                    </div>
                    <div class="row">
                    	<?php 
                    	$args = new \WP_Query(array(   
                    		'post_type' => 'post', 
                    		'posts_per_page'=> $post_number_3,
                    		'order'         => $order_3,
                    	));  
                    	if($args->have_posts()):
                    		while ($args -> have_posts()) : $args -> the_post(); 
                    			$image_home3 = get_post_meta(get_the_ID(),'_cmb_image_home3', true); 
                    			?>
                        <div class="col-xl-6 col-lg-6 col-md-6">
                            <div class="blog-2-wrapper mb-30">
                                <div class="blog-2-img">
                                    <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url($image_home3);?>" alt=""></a>
                                    <div class="blog-2-text">
                                        <div class="blog-meta">
                                            <span> <i class="far fa-user"></i> <?php the_author_posts_link(); ?> </span>
                                            <span> <i class="fal fa-calendar-alt"></i> <?php the_time(get_option( 'date_format'));?></span>
                                            <span> <i class="far fa-comments"></i> <?php comments_number( esc_html__('(0)', 'anondho'), 
                                  esc_html__('(01)', 'anondho'), esc_html__('(%)', 'anondho') ); ?></span>
                                        </div>
                                        <h3><a href="<?php the_permalink();?>"><?php the_title();?></a></h3>
                                        <a href="<?php the_permalink();?>"><?php if(isset($anondho_redux_demo['read_more'])){?>
                                        <?php echo htmlspecialchars_decode(esc_attr($anondho_redux_demo['read_more']));?>
                                        <?php }else{?>
                                        <?php echo esc_html__( 'Read more', 'anondho' );}?></a>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php 
                    endwhile;  
                    wp_reset_postdata();
                endif; 
                ?>
                    </div>
                </div>
            </div>
        <?php endif; ?>	
	<?php
	}

}