<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsBooking extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-booking';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Booking Area', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'booking' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_booking',
			[
				'label' => esc_html__( 'Booking', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'booking-style-1'  => esc_html__( 'Booking Style 1', 'bdevs-elementor' ),
					'booking-style-2' => esc_html__( 'Booking Style 2', 'bdevs-elementor' ),
					'booking-style-3' => esc_html__( 'Booking Style 3', 'bdevs-elementor' ),
				],
				'default'   => 'booking-style-1',
			]
		);

		$this->add_control(
			'image1',
			[
				'label'   => esc_html__( 'Booking Image 1', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Booking Image', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'image2',
			[
				'label'   => esc_html__( 'Booking Image 2', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Booking Image', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'image3',
			[
				'label'   => esc_html__( 'Booking Image 3', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Booking Image', 'bdevs-elementor' ),
			]
		);


		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'shortcode_1',
			[
				'label'       => __( 'Contact Form', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Contact Form', 'bdevs-elementor' ),
				'default'     => __( 'It is Contact Form', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_booking_2',
			[
				'label' => esc_html__( 'Booking Area 2', 'bdevs-elementor' ),
			]
		);


		$this->add_control(
			'image_home_3',
			[
				'label'   => esc_html__( 'Booking Image 1', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Booking Image', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'image_2_home_3',
			[
				'label'   => esc_html__( 'Booking Image 2', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Booking Image', 'bdevs-elementor' ),
			]
		);


		$this->add_control(
			'heading_2',
			[
				'label'       => __( 'Heading Home 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		$this->add_control(
			'sub_heading_2',
			[
				'label'       => __( 'Sub Heading Home 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading home 3', 'bdevs-elementor' ),
				'default'     => __( 'It is sub heading home 3', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	


		$this->add_control(
			'booking_form',
			[
				'label'       => __( 'Booking Form', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Booking Form', 'bdevs-elementor' ),
				'default'     => __( 'It is sub Booking Form', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	


		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_booking_3',
			[
				'label' => esc_html__( 'Booking Area 3', 'bdevs-elementor' ),
			]
		);


		$this->add_control(
			'image1_event',
			[
				'label'   => esc_html__( 'Booking Image 1', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Booking Image', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'image2_event',
			[
				'label'   => esc_html__( 'Booking Image 2', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Booking Image', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'image3_event',
			[
				'label'   => esc_html__( 'Booking Image 3', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Booking Image', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'image4_event',
			[
				'label'   => esc_html__( 'Booking Image 4', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Booking Image', 'bdevs-elementor' ),
			]
		);


		$this->add_control(
			'heading_event',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'shortcode_1_event',
			[
				'label'       => __( 'Contact Form', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Contact Form', 'bdevs-elementor' ),
				'default'     => __( 'It is Contact Form', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);
		

		$this->end_controls_section();




		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->add_control(
			'show_content',
			[
				'label'   => esc_html__( 'Show Content', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

		

		$this->start_controls_section(
			'section_content_button',
			[
				'label'     => esc_html__( 'Button', 'bdevs-elementor' ),
				'condition' => [
					'show_button' => 'yes',
				],
			]
		);

		$this->add_control(
			'button_text',
			[
				'label'       => esc_html__( 'Button Text', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Read More', 'bdevs-elementor' ),
				'placeholder' => esc_html__( 'Read More', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'icon',
			[
				'label'       => esc_html__( 'Icon', 'bdevs-elementor' ),
				'type'        => Controls_Manager::ICON,
				'label_block' => true,
			]
		);

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		$chose_style = $settings['chose_style'];
		extract($settings);

		if( $chose_style == 'booking-style-1' ): ?>
		<div class="booking-area grad-bg pos-rel pt-135 pb-135">
                <div class="shape d-none d-xl-block">
                	<?php if (( '' !== $settings['image1']['url'] ) && ( $settings['show_image'] )): ?>
                    <div class="shape-item fa-01 rotateme"><img src="<?php echo wp_kses_post($settings['image1']['url']); ?>" alt=""></div>
                    <?php endif; ?>	

                    <?php if (( '' !== $settings['image2']['url'] ) && ( $settings['show_image'] )): ?>
                    <div class="shape-item fa-02 rotateme"><img src="<?php echo wp_kses_post($settings['image2']['url']); ?>" alt=""></div>
                    <?php endif; ?>	
                </div>
                <?php if (( '' !== $settings['image3']['url'] ) && ( $settings['show_image'] )): ?>
                <div class="booking-bg-img d-none d-md-block" style="background-image:url(<?php echo wp_kses_post($settings['image3']['url']); ?>);"></div>
                <?php endif; ?>	
                <div class="container-fluid">
                    <div class="row">
                        <div class="col-xl-6 offset-xl-6 col-lg-6 offset-lg-6 col-md-6 offset-md-6">
                            <div class="booking-wrapper">
                            	<?php if (( '' !== $settings['heading'] ) && ( $settings['show_title'] )): ?>
                                <div class="booking-text">
                                    <h1><?php echo wp_kses_post($settings['heading']); ?></h1>
                                </div>
                                <?php endif; ?>
                                <?php print do_shortcode(html_entity_decode( $settings['shortcode_1'] )); ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php elseif( $chose_style == 'booking-style-2' ): ?>
        	<?php if (( '' !== $settings['image_home_3']['url'] ) && ( $settings['show_image'] )): ?>
        	<div class="booking-2-area  pt-120 pb-100" style="background-image:url(<?php echo wp_kses_post($settings['image_home_3']['url']); ?>)">
        		<?php endif; ?>	
                <div class="container-fluid container-2-padding">
                    <div class="row">
                        <div class="col-xl-6">
                            <div class="area-title-light pb-75">
                                <?php if (( '' !== $settings['heading_2'] ) && ( $settings['show_title'] )): ?>
									<h1><?php echo wp_kses_post($settings['heading_2']); ?> </h1>
									<?php endif; ?>
                                <?php if (( '' !== $settings['sub_heading_2'] ) && ( $settings['show_content'] )): ?>
									<p><?php echo wp_kses_post($settings['sub_heading_2']); ?></p>
									<?php endif; ?>	
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-xl-7 col-lg-7">
                        	<?php if ( '' !== $settings['booking_form'] ) : ?>
                            <div class="booking-2-wrapper mb-30">
                                <?php echo wp_kses_post($settings['booking_form']); ?>
                            </div>
                            <?php endif; ?>	
                        </div>
                        <div class="col-xl-5 col-lg-5">
                        	<?php if ( '' !== $settings['image_2_home_3']['url'] ): ?>
                            <div class="booking-img mb-30">
                                <img src="<?php echo wp_kses_post($settings['image_2_home_3']['url']); ?>" alt="">
                            </div>
                            <?php endif; ?>	
                        </div>
                    </div>
                </div>
            </div>
        <?php elseif( $chose_style == 'booking-style-3' ): ?>
        	<div class="booking-area theme-bg pos-rel pt-135 pb-135">
                    <div class="shape d-none d-xl-block">
                    	<?php if ( '' !== $settings['image1_event']['url'] ) : ?>
	                    	<div class="shape-item fa-01 rotateme"><img src="<?php echo wp_kses_post($settings['image1_event']['url']); ?>" alt=""></div>
	                    <?php endif; ?>	
	                    <?php if ( '' !== $settings['image2_event']['url'] ) : ?>
		                    <div class="shape-item fa-02 rotateme"><img src="<?php echo wp_kses_post($settings['image2_event']['url']); ?>" alt=""></div>
		                <?php endif; ?>	
		                <?php if ( '' !== $settings['image3_event']['url'] ) : ?>
			                <div class="shape-item fa-03 rotateme"><img src="<?php echo wp_kses_post($settings['image3_event']['url']); ?>" alt=""></div>
			            <?php endif; ?>	
                    </div>
                     <?php if (( '' !== $settings['image4_event']['url'] ) && ( $settings['show_image'] )): ?>
                    <div class="booking-bg-img d-none d-md-block" style="background-image:url(<?php echo wp_kses_post($settings['image4_event']['url']); ?>);"></div>
                    <?php endif; ?>	
                    <div class="container-fluid">
                        <div class="row">
                            <div class="col-xl-6 offset-xl-6 col-lg-6 offset-lg-6 col-md-6 offset-md-6">
                                <div class="booking-wrapper">
                                	<?php if (( '' !== $settings['heading_event'] ) && ( $settings['show_title'] )): ?>
	                                	<div class="booking-text">
	                                		<h1><?php echo wp_kses_post($settings['heading_event']); ?></h1>
	                                	</div>
	                                <?php endif; ?>
                                    <?php print do_shortcode(html_entity_decode( $settings['shortcode_1_event'] )); ?>
                                </div>
                            </div>
                        </div>
                    </div>
            </div>
        <?php endif; ?>	
	<?php
	}

}