<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsClient extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-client';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Client', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'client' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_client',
			[
				'label' => esc_html__( 'Client Area', 'bdevs-elementor' ),
			]	
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'client-style-1'  => esc_html__( 'Client Style 1', 'bdevs-elementor' ),
					'client-style-2' => esc_html__( 'Client Style 2', 'bdevs-elementor' ),
				],
				'default'   => 'client-style-1',
			]
		);

		$this->add_control(
			'image',
			[
				'label'       => __( 'Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Image', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_heading',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is sub heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Client Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Client #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [	
					[
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],			
					[
						'name'        => 'tab_title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Title' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_subtitle',
						'label'       => esc_html__( 'Subtitle', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Subtitle' , 'bdevs-elementor' ),
						'label_block' => true,
					],	
					[
						'name'        => 'tab_content',
						'label'       => esc_html__( 'Content', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Content' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);


		$this->end_controls_section();


		$this->start_controls_section(
			'section_content_client_2',
			[
				'label' => esc_html__( 'Client Area 2', 'bdevs-elementor' ),
			]
		);




		$this->add_control(
			'heading_2',
			[
				'label'       => __( 'Heading Home 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		$this->add_control(
			'sub_heading_2',
			[
				'label'       => __( 'Sub Heading Home 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading home 3', 'bdevs-elementor' ),
				'default'     => __( 'It is sub heading home 3', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		
		$this->add_control(
			'tabs_2',
			[
				'label' => esc_html__( 'Client Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Client #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [	
					[
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],			
					[
						'name'        => 'tab_title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Title' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_subtitle',
						'label'       => esc_html__( 'Subtitle', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Subtitle' , 'bdevs-elementor' ),
						'label_block' => true,
					],	
					[
						'name'        => 'tab_content',
						'label'       => esc_html__( 'Content', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Content' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		

		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);			

		$this->add_control(
			'show_sub_heading',
			[
				'label'   => esc_html__( 'Show Sub Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);



		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		$chose_style = $settings['chose_style'];
		extract($settings);
		
		if( $chose_style == 'client-style-1' ): ?>
		 <div class="client-area pt-130 pb-85">
            <div class="container">
                <div class="row">
                    <div class="col-xl-5 col-lg-5 mb-30">
                    	<?php if (( '' !== $settings['image']['url'] ) && ( $settings['show_image'] )): ?>
                        <div class="client-img">
                            <img src="<?php echo wp_kses_post($settings['image']['url']); ?>" alt="">
                        </div>
                        <?php endif; ?>
                    </div>
                    <div class="col-xl-7 col-lg-7">
                        <div class="inner-client">
                            <div class="area-title pb-45">
                                <span></span>
                                <?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )): ?>
                                <h1 class="mb-0"><?php echo wp_kses_post($settings['heading']); ?></h1>
                                <?php endif; ?>
                                <?php if (( '' !== $settings['sub_heading'] ) && ( $settings['show_sub_heading'] )): ?>
                                <p><?php echo wp_kses_post($settings['sub_heading']); ?></p>
                                <?php endif; ?>
                            </div>
                            <div class="client-active owl-carousel">
                            	<?php foreach ( $settings['tabs'] as $item ) : ?>
                                <div class="client-wrapper">
                                    <div class="client-text">
                                    	<?php if ( '' !== $item['tab_content'] ) : ?>
                                        <p><?php echo wp_kses_post($item['tab_content']); ?></p>
                                        <?php endif; ?>
                                        <div class="client-name">
                                            <div class="client-1-img">
                                            	<?php if ( '' !== $item['tab_image']['url'] ) : ?>
                                                <img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt="">
                                                <?php endif; ?>
                                            </div>
                                            <div class="client-content">
                                            	<?php if ( '' !== $item['tab_title'] ) : ?>
                                                <h4><?php echo wp_kses_post($item['tab_title']); ?> </h4>
                                                <?php endif; ?>
                                                <?php if ( '' !== $item['tab_subtitle'] ) : ?>
                                                <span><?php echo wp_kses_post($item['tab_subtitle']); ?></span>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <?php
                            endforeach;
                            ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           $('.client-active').owlCarousel({

		loop: true,

		nav: true,

		dots: false,

		autoplay: false,

		navText: ['<i class="far fa-long-arrow-alt-left"></i>', '<i class="far fa-long-arrow-alt-right"></i>'],

		responsive: {

			0: {

				items: 1,

				nav: false,

			},

			576: {

				items: 1

			},

			768: {

				items: 1

			},

			992: {

				items: 1

			},

			1200: {

				items: 1

			}

		}

	}) 
        
        
    </script>   
    <?php } ?>
		<?php elseif( $chose_style == 'client-style-2' ): ?>
        <div class="client-area dark pt-120 pb-110">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-8 col-lg-8 offset-lg-2 offset-xl-2">
                            <div class="area-title-light text-center pb-75">
                            	<?php if (( '' !== $settings['heading_2'] ) && ( $settings['show_heading'] )): ?>
                                <h1><?php echo wp_kses_post($settings['heading_2']); ?></h1>
                                <?php endif; ?>
                                <?php if (( '' !== $settings['sub_heading_2'] ) && ( $settings['show_sub_heading'] )): ?>
                                <p><?php echo wp_kses_post($settings['sub_heading_2']); ?> </p>
                            	<?php endif; ?>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="client-say-active owl-carousel">
							<?php foreach ( $settings['tabs_2'] as $item ) : ?>
                            <div class="col-xl-12">
                                <div class="client-say-wrapper mb-30">
                                    <div class="client-say-text">
                                    	<?php if ( '' !== $item['tab_content'] ): ?>
                                        	<p><?php echo wp_kses_post($item['tab_content']); ?></p>
                                    	<?php endif; ?>
                                        <div class="clientsay-name">
                                        	<?php if ( '' !== $item['tab_image']['url'] ): ?>
                                            <div class="client-say-img">
                                                <img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt="">
                                            </div>
                                            <?php endif; ?>
                                            <div class="client-say-content">
                                                <?php if ( '' !== $item['tab_title'] ) : ?>
                                                <h4><?php echo wp_kses_post($item['tab_title']); ?> </h4>
                                                <?php endif; ?>
                                                <?php if ( '' !== $item['tab_subtitle'] ) : ?>
                                                <span><?php echo wp_kses_post($item['tab_subtitle']); ?></span>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <?php
                            endforeach;
                            ?>
                        </div>
                    </div>
                </div>
            </div>
		<?php endif; ?>	
<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           $('.client-say-active').owlCarousel({

		loop: true,

		nav: false,

		dots: false,

		margin:0,

		autoplay: true,

		navText: ['<i class="fas fa-angle-left"></i>', '<i class="fas fa-angle-right"></i>'],

		responsive: {

			0: {

				items: 1

			},

			576: {

				items: 1

			},

			768: {

				items: 2

			},

			992: {

				items: 3

			},

			1200: {

				items: 4

			}

		}

	})
        
        
    </script>   
    <?php } ?>
	<?php
	}

}