<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsFaq extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-faq';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Faq', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'faq' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_faq',
			[
				'label' => esc_html__( 'FAQ', 'bdevs-elementor' ),
			]	
		);


		
		$this->add_control(
			'image',
			[
				'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Image', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Heading', 'bdevs-elementor' ),
				'default'     => __( 'Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);


		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'FAQ Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'FAQ #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [		
					[
						'name'        => 'tab_title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Title' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_content',
						'label'       => esc_html__( 'Content', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Content' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_link',
						'label'       => esc_html__( 'Link', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Link' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_id',
						'label'       => esc_html__( 'Tab ID', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab ID' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_id_2',
						'label'       => esc_html__( 'Tab ID 2', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab ID 2' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		

		$this->end_controls_section();		

		
		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);

		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->add_control(
			'show_content',
			[
				'label'   => esc_html__( 'Show Content', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		extract($settings);
		?>
		<div class="faq-area pb-85">
            <div class="container">
                <div class="row">
                    <div class="col-xl-6 col-lg-6">
                    	<?php if (( '' !== $settings['image']['url'] ) && ( $settings['show_image'] )): ?>
                        <div class="faq-img mb-30">
                            <img class="bounce-animate" src="<?php echo wp_kses_post($settings['image']['url']); ?>" alt="">
                        </div>
                        <?php endif; ?>	
                    </div>
                    <div class="col-xl-6 col-lg-6">
                        <div class="faq-box mb-30">
                        	<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )): ?>
                            <div class="section-title section-2-title section-title-left">
                                <h2><?php echo wp_kses_post($settings['heading']); ?></h2>
                            </div>
                            <?php endif; ?>	
                            <div id="accordion" class="mt-50">
                            	<?php $i=1; foreach ( $settings['tabs'] as $item ) : ?>
                            	<?php if ($i==1) { ?>
                                <div class="card">
                                    <div class="card-header" id="<?php echo wp_kses_post($item['tab_id']); ?>">
                                    	<?php if ( '' !== $item['tab_title'] ) : ?>
                                        <h5 class="mb-0">
                                            <a href="<?php echo wp_kses_post($item['tab_link']); ?>" class="btn-link" data-toggle="collapse" data-target="#<?php echo wp_kses_post($item['tab_id_2']); ?>" aria-expanded="false" aria-controls="<?php echo wp_kses_post($item['tab_id_2']); ?>">
                                                <?php echo wp_kses_post($item['tab_title']); ?>
                                            </a>
                                        </h5>
                                        <?php endif; ?>	
                                    </div>

                                    <div id="<?php echo wp_kses_post($item['tab_id_2']); ?>" class="collapse show" aria-labelledby="<?php echo wp_kses_post($item['tab_id']); ?>" data-parent="#accordion" >
                                        <div class="card-body">
                                            <p><?php echo wp_kses_post($item['tab_content']); ?></p>
                                        </div>
                                    </div>
                                </div>
								<?php }else { ?>
                                <div class="card">
                                    <div class="card-header" id="<?php echo wp_kses_post($item['tab_id']); ?>">
                                        <h5 class="mb-0">
                                            <a href="<?php echo wp_kses_post($item['tab_link']); ?>" class="btn-link collapsed" data-toggle="collapse" data-target="#<?php echo wp_kses_post($item['tab_id_2']); ?>" aria-expanded="false" aria-controls="<?php echo wp_kses_post($item['tab_id_2']); ?>">
                                                <?php echo wp_kses_post($item['tab_title']); ?>
                                            </a>
                                        </h5>
                                    </div>
                                    <div id="<?php echo wp_kses_post($item['tab_id_2']); ?>" class="collapse" aria-labelledby="<?php echo wp_kses_post($item['tab_id']); ?>" data-parent="#accordion">
                                        <div class="card-body">
                                            <p><?php echo wp_kses_post($item['tab_content']); ?></p>
                                        </div>
                                    </div>
                                </div>

                            	<?php } ?>

                                <?php $i++; endforeach; ?>
                            </div>
                        </div>
                    </div>

                </div>
            </div>
        </div>
	<?php
	}
}