<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsFeatures extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-features';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Features List', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'features' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_features',
			[
				'label' => esc_html__( 'Features', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'features_home_1'  => esc_html__( 'Features Home 1', 'bdevs-elementor' ),
					'features_home_2' => esc_html__( 'Features Home 2', 'bdevs-elementor' ),
					'features_home_3' => esc_html__( 'Features Home 3', 'bdevs-elementor' ),
					'features_style_4' => esc_html__( 'Features Style 4', 'bdevs-elementor' ),
				],
				'default'   => 'features_home_1',
			]
		);

		$this->add_control(
			'image',
			[
				'label'   => esc_html__( 'Features Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Features Image', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_heading',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Sub Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	


		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Feature Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Feature One', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Feature Two', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Support Content Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Feature Three', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
				],
				'fields' => [	
					[
						'name'        => 'tab_icon',
						'label'       => esc_html__( 'Icon', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'fal fa-glass-cheers' , 'bdevs-elementor' ),
						'label_block' => true,
					],		
					
					[
						'name'        => 'tab_heading',
						'label'       => esc_html__( 'Heading', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Heading' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'tab_sub_heading',
						'label'       => esc_html__( 'Sub Heading', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Sub Heading' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Feature Title' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'       => 'tab_content',
						'label'      => esc_html__( 'Content', 'bdevs-elementor' ),
						'type'       => Controls_Manager::WYSIWYG,
						'dynamic'    => [ 'active' => true ],
						'default'    => esc_html__( 'Feature Content', 'bdevs-elementor' ),
						'show_label' => false,
					],
					[
						'name'        => 'tab_link',
						'label'       => esc_html__( 'Link', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
					],

					[
						'name'       => 'tab_button',
						'label'      => esc_html__( 'Button', 'bdevs-elementor' ),
						'type'       => Controls_Manager::TEXT,
						'dynamic'    => [ 'active' => true ],
						'default'    => esc_html__( 'Tab Button', 'bdevs-elementor' ),
					],
				],
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Features Home 2', 'bdevs-elementor' ),
				
			]
		);

		$this->add_control(
			'tabs2',
			[
				'label' => esc_html__( 'Feature Items 2', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Feature One', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Feature Two', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Support Content Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Feature Three', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
				],
				'fields' => [	
					[
						'name'        => 'tab_title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Feature Title' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_icon',
						'label'       => esc_html__( 'Icon', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Icon' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'section_content_home_3',
			[
				'label' => esc_html__( 'Features Home 3', 'bdevs-elementor' ),
				
			]
		);

		$this->add_control(
			'tabs_home_3',
			[
				'label' => esc_html__( 'Feature Items 3', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Feature One', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Feature Two', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Support Content Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Feature Three', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
				],
				'fields' => [	
					[
						'name'        => 'tab_title_home_3',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Feature Title' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_subtitle_home_3',
						'label'       => esc_html__( 'Subtitle', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Feature Subtitle' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_icon_home_3',
						'label'       => esc_html__( 'Icon', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Feature Icon' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_features_4',
			[
				'label' => esc_html__( 'Features Style 4', 'bdevs-elementor' ),
				
			]
		);

		$this->add_control(
			'heading_4',
			[
				'label'       => __( 'Heading 4', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading 4', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading 4', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_heading_4',
			[
				'label'       => __( 'Sub Heading 4', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading 4', 'bdevs-elementor' ),
				'default'     => __( 'It is Sub Heading 4', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	


		$this->add_control(
			'tabs_4',
			[
				'label' => esc_html__( 'Feature Items 4', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Feature One', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Feature Two', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Support Content Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Feature Three', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
				],
				'fields' => [	
				    [
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Feature Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],
					[
						'name'        => 'tab_heading',
						'label'       => esc_html__( 'Heading', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Heading' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_sub_heading',
						'label'       => esc_html__( 'Sub Heading', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Sub Heading' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Feature Title' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'       => 'tab_content',
						'label'      => esc_html__( 'Content', 'bdevs-elementor' ),
						'type'       => Controls_Manager::WYSIWYG,
						'dynamic'    => [ 'active' => true ],
						'default'    => esc_html__( 'Feature Content', 'bdevs-elementor' ),
						'show_label' => false,
					],
					[
						'name'        => 'tab_link',
						'label'       => esc_html__( 'Link', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'    => esc_html__( 'Feature Content', 'bdevs-elementor' ),
						'show_label' => false,
					],

					[
						'name'       => 'tab_button',
						'label'      => esc_html__( 'Button', 'bdevs-elementor' ),
						'type'       => Controls_Manager::TEXT,
						'dynamic'    => [ 'active' => true ],
						'default'    => esc_html__( 'Tab Button', 'bdevs-elementor' ),
					],
				],
			]
		);

		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->add_control(
			'show_content',
			[
				'label'   => esc_html__( 'Show Content', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

		

		$this->start_controls_section(
			'section_content_button',
			[
				'label'     => esc_html__( 'Button', 'bdevs-elementor' ),
				'condition' => [
					'show_button' => 'yes',
				],
			]
		);

		$this->add_control(
			'button_text',
			[
				'label'       => esc_html__( 'Button Text', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Read More', 'bdevs-elementor' ),
				'placeholder' => esc_html__( 'Read More', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'icon',
			[
				'label'       => esc_html__( 'Icon', 'bdevs-elementor' ),
				'type'        => Controls_Manager::ICON,
				'label_block' => true,
			]
		);

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		$chose_style = $settings['chose_style'];
		?>
		<?php if( $chose_style == 'features_home_1' ): ?>

		<?php if ( '' !== $settings['image']['url'] ) : ?>
		<div class="features-title-area pt-180 pb-385" style="background-image:url(<?php echo wp_kses_post($settings['image']['url']); ?>)">
		<?php endif; ?>	
                <div class="container">
                    <div class="row">
                        <div class="col-xl-8 col-lg-8 offset-lg-2 offset-xl-2">
                            <div class="section-title white-title text-center">
                                <h1><?php echo wp_kses_post($settings['heading']); ?></h1>
                                <h2><?php echo wp_kses_post($settings['sub_heading']); ?></h2>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="features-area pl-135 pr-135 pb-140">
                <div class="container-fluid">
                    <div class="features-bg">
                        <div class="row">
					<?php 
					foreach ( $settings['tabs'] as $item ) : ?>

						<div class="col-xl-3 col-lg-3 col-md-6 col-sm-6">
							<div class="features-wrapper text-center mb-30">
								<div class="features-img">
									<div class="features-content">
										<i class="<?php echo wp_kses_post($item['tab_icon']); ?>"></i>
										<?php if ( '' !== $item['tab_title'] ) : ?>
										<h3><?php echo wp_kses_post($item['tab_title']); ?></h3>
										<?php endif; ?>	
										<?php if ( '' !== $item['tab_content'] ) : ?>
										<?php echo wp_kses_post($item['tab_content']); ?>
										<?php endif; ?>	
										<?php if (( '' !== $item['tab_button'] ) && ( $settings['show_button'] )) : ?>
										<a class="btn-bb" href="<?php echo wp_kses_post($item['tab_link']); ?>"><?php echo wp_kses_post($item['tab_button']); ?></a>
										<?php endif; ?>
									</div>
								</div>
							</div>
						</div>
					<?php
					endforeach;
					?>
			
				</div>
			</div>
		</div>
	</div>
		<?php elseif( $chose_style == 'features_home_2' ): ?>
			<div class="features-menu-area fix grey-bg">
				<div class="row no-gutters">
					<?php $counter = 1; ?>
					<?php foreach ( $settings['tabs2'] as $item ) : ?>
						<div class="col-xl-3 col-lg-3 col-md-6 col-sm-6">
							<div class="features-menu-wrapper pt-55 pb-55 text-center">
								<div class="inner-features">
									<?php if ( '' !== $item['tab_icon'] )  : ?>
									<div class="features-menu-icon">
										<i class="fal <?php echo wp_kses_post($item['tab_icon']); ?>"></i>
									</div>
									<?php endif; ?>
									<?php if (( '' !== $item['tab_title'] ) && ( $settings['show_title'] )) : ?>
									<div class="features-menu-text">
										<h3><?php echo wp_kses_post($item['tab_title']); ?></h3>
									</div>
									<?php endif; ?>
								</div>
							</div>
						</div>
					<?php
					$counter++;
				endforeach;
				?>
				</div>
			</div>
		<?php elseif( $chose_style == 'features_home_3' ): ?>
			<div class="features-01-area dark pt-130 pb-90">
                <div class="container">
                    <div class="row">
                    	<?php foreach ( $settings['tabs_home_3'] as $item ) : ?>
                        <div class="col-xl-3 col-lg-3 col-md-6 mb-30">
                            <div class="features-01-wrapper">
                            	<?php if ( '' !== $item['tab_icon_home_3'] )  : ?>
                                <div class="features-01-icon">
                                    <i class="<?php echo wp_kses_post($item['tab_icon_home_3']); ?>"></i>
                                </div>
                                <?php endif; ?>
                                <div class="features-01-text">
                                	<?php if (( '' !== $item['tab_title_home_3'] ) && ( $settings['show_title'] )) : ?>
                                    <h3><?php echo wp_kses_post($item['tab_title_home_3']); ?></h3>
                                    <?php endif; ?>
                                    <?php if (( '' !== $item['tab_subtitle_home_3'] ) && ( $settings['show_content'] )) : ?>
                                    <p><?php echo wp_kses_post($item['tab_subtitle_home_3']); ?></p>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                        <?php
                    endforeach;
                    ?>
                    </div>
                </div>
            </div>
        <?php elseif( $chose_style == 'features_style_4' ): ?>
        	<div class="features-1-area pl-135 pr-135 pb-90 pt-125">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-6 offset-xl-3 col-lg-6 offset-lg-3">
                            <div class="upcoming-title upcoming-title-black text-center mb-80">
                                <span><?php echo wp_kses_post($settings['heading_4']); ?></span>
                                <h1><?php echo wp_kses_post($settings['sub_heading_4']); ?></h1>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="container-fluid">
                    <div class="features-bg">
                        <div class="row">
                        	<?php foreach ( $settings['tabs_4'] as $item ) : ?>
                            <div class="col-xl-3 col-lg-3 col-md-6">
							<div class="features-wrapper text-center mb-30">
								<div class="features-img">
									<?php if (( '' !== $item['tab_image']['url'] ) && ( $settings['show_image'] )): ?>
									<img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt="">
									<?php endif; ?>	
									<div class="features-content">
										<?php if ( '' !== $item['tab_title'] ) : ?>
										<h3><?php echo wp_kses_post($item['tab_title']); ?></h3>
										<?php endif; ?>	

										<?php if ( '' !== $item['tab_content'] )  : ?>
										<?php echo wp_kses_post($item['tab_content']); ?>
										<?php endif; ?>	

										<?php if (( '' !== $item['tab_button'] ) && ( $settings['show_button'] )) : ?>
										<a class="btn" href="<?php echo wp_kses_post($item['tab_link']); ?>"><span class="btn-text"><?php echo wp_kses_post($item['tab_button']); ?></span> <span class="btn-border"></span></a>
										<?php endif; ?>
									</div>
								</div>
								<div class="features-text">
									<?php if (( '' !== $item['tab_heading'] ) && ( $settings['show_title'] )): ?>
										<h3><?php echo wp_kses_post($item['tab_heading']); ?></h3>
									<?php endif; ?>

									<?php if (( '' !== $item['tab_sub_heading'] ) && ( $settings['show_content'] )) : ?>
										<p><?php echo wp_kses_post($item['tab_sub_heading']); ?></p>
									<?php endif; ?>	
								</div>
							</div>
						</div>
                            <?php
                    endforeach;
                    ?>
                        </div>
                    </div>
                </div>
            </div>
		<?php endif; ?>	
	<?php
	}

}