<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsGallery2 extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-gallery2';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Our Gallery 2', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs gallery widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs gallery widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'gallery2' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_gallery',
			[
				'label' => esc_html__( 'Gallery', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'gallery_1'  => esc_html__( 'Gallery 1', 'bdevs-elementor' ),
					'gallery_2' => esc_html__( 'Gallery 2', 'bdevs-elementor' ),
					'gallery_3' => esc_html__( 'Gallery 3', 'bdevs-elementor' ),
				],
				'default'   => 'gallery_1',
			]
		);

		$this->add_control(
			'image',
			[
				'label'   => esc_html__( 'Gallery Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your gallery Image', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_heading',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	


		$this->add_control(
			'post_number',
			[
				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'3'  => esc_html__( '3', 'bdevs-elementor' ),
					'5' => esc_html__( '5', 'bdevs-elementor' ),
					'9' => esc_html__( '9', 'bdevs-elementor' ),
					'12' => esc_html__( '12', 'bdevs-elementor' ),
				],
				'default'   => '5',
			]
		);

		$this->add_control(
			'post_order',
			[
				'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
					'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
				],
				'default'   => 'desc',
			]
		);


		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_gallery_2',
			[
				'label' => esc_html__( 'Gallery 2', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'image_2',
			[
				'label'   => esc_html__( 'Gallery Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your gallery Image', 'bdevs-elementor' ),
			]
		);


		$this->add_control(
			'heading_2',
			[
				'label'       => __( 'Heading 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_heading_2',
			[
				'label'       => __( 'Sub heading 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'title_2',
			[
				'label'       => __( 'Title 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Title', 'bdevs-elementor' ),
				'default'     => __( 'It is Title', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	


		$this->add_control(
			'link',
			[
				'label'       => __( 'Link', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter link', 'bdevs-elementor' ),
				'default'     => __( 'It is Link', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'button',
			[
				'label'       => __( 'Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter text button', 'bdevs-elementor' ),
				'default'     => __( 'It is Text Button', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'tabs1',
			[
				'label' => esc_html__( 'Gallery Items 1', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Gallery #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Gallery #2', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					],
				],
				'fields' => [					
									
					[
						'name'        => 'video_link',
						'label'       => esc_html__( 'Link Video', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => __( 'It is Video Link.', 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'       => 'tab_link',
						'label'      => esc_html__( 'Link', 'bdevs-elementor' ),
						'type'       => Controls_Manager::TEXT,
						'dynamic'    => [ 'active' => true ],
						'default'     => __( 'It is Link.', 'bdevs-elementor' ),
						'show_label' => false,
					],
					[
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Tab Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],	
				],
			]
		);

		$this->add_control(
			'tabs2',
			[
				'label' => esc_html__( 'Gallery Items 2', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Gallery #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Gallery #2', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					],
				],
				'fields' => [				
					[
						'name'        => 'video_link',
						'label'       => esc_html__( 'Link Video', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => __( 'It is Video Link.', 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'       => 'tab_link',
						'label'      => esc_html__( 'Link', 'bdevs-elementor' ),
						'type'       => Controls_Manager::TEXT,
						'dynamic'    => [ 'active' => true ],
						'default'     => __( 'It is Link.', 'bdevs-elementor' ),
						'show_label' => false,
					],
					[
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Tab Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],	
				],
			]
		);

		$this->add_control(
			'tabs3',
			[
				'label' => esc_html__( 'Gallery Items 3', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Gallery #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Gallery #2', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					],
				],
				'fields' => [					
									
					[
						'name'        => 'video_link',
						'label'       => esc_html__( 'Link Video', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => __( 'It is Video Link.', 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'       => 'tab_link',
						'label'      => esc_html__( 'Link', 'bdevs-elementor' ),
						'type'       => Controls_Manager::TEXT,
						'dynamic'    => [ 'active' => true ],
						'default'     => __( 'It is Link.', 'bdevs-elementor' ),
						'show_label' => false,
					],
					[
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Tab Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],	
				],
			]
		);

		$this->add_control(
			'tabs4',
			[
				'label' => esc_html__( 'Gallery Items 4', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Gallery #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Gallery #2', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					],
				],
				'fields' => [					
									
					[
						'name'        => 'video_link',
						'label'       => esc_html__( 'Link Video', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => __( 'It is Video Link.', 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'       => 'tab_link',
						'label'      => esc_html__( 'Link', 'bdevs-elementor' ),
						'type'       => Controls_Manager::TEXT,
						'dynamic'    => [ 'active' => true ],
						'default'     => __( 'It is Link.', 'bdevs-elementor' ),
						'show_label' => false,
					],
					[
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Tab Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],	
				],
			]
		);

		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_gallery_3',
			[
				'label' => esc_html__( 'Gallery 3', 'bdevs-elementor' ),
			]
		);


		$this->add_control(
			'heading_3',
			[
				'label'       => __( 'Heading 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_heading_3',
			[
				'label'       => __( 'Sub heading 3', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		
		$this->add_control(
			'tabs5',
			[
				'label' => esc_html__( 'Gallery Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Gallery #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Gallery #2', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					],
				],
				'fields' => [					
									
					[
						'name'        => 'video_link',
						'label'       => esc_html__( 'Link Video', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => __( 'It is Video Link.', 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Tab Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],	
				],
			]
		);

		$this->end_controls_section();


		

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->add_control(
			'show_content',
			[
				'label'   => esc_html__( 'Show Content', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

		

		$this->start_controls_section(
			'section_content_button',
			[
				'label'     => esc_html__( 'Button', 'bdevs-elementor' ),
				'condition' => [
					'show_button' => 'yes',
				],
			]
		);

		$this->add_control(
			'button_text',
			[
				'label'       => esc_html__( 'Button Text', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Read More', 'bdevs-elementor' ),
				'placeholder' => esc_html__( 'Read More', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'icon',
			[
				'label'       => esc_html__( 'Icon', 'bdevs-elementor' ),
				'type'        => Controls_Manager::ICON,
				'label_block' => true,
			]
		);

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		$chose_style = $settings['chose_style'];
		$order = $settings['post_order'];
		$post_number = $settings['post_number'];

		$wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'gallery',  'orderby' => 'ID', 'order' => 'ASC'));
	    

	    //other style
	    $args = array('posts_per_page' => $post_number,'post_type' => 'gallery',  'orderby' => 'ID', 'order' => 'ASC');

		?>
		<?php if( $chose_style == 'gallery_1' ): ?>
		<?php if (( '' !== $settings['image']['url'] ) && ( $settings['show_image'] )): ?>
        <div class="gallery-2-area pt-120 pb-440 pl-55 pr-55" style="background-image:url(<?php echo wp_kses_post($settings['image']['url']); ?>)">
        	<?php endif; ?>	
                <div class="container">
                    <div class="row">
                        <div class="col-xl-8 col-lg-8 offset-lg-2 offset-xl-2">
                            <div class="area-title-light text-center pb-75">
                                <?php if (( '' !== $settings['heading'] ) && ( $settings['show_title'] )): ?>
                                <h1><?php echo wp_kses_post($settings['heading']); ?></h1>
                                <?php endif; ?>	
                                <?php if (( '' !== $settings['sub_heading'] ) && ( $settings['show_content'] )): ?>
                                <p><?php echo wp_kses_post($settings['sub_heading']); ?></p>
                                <?php endif; ?>	
                            </div>
                        </div>
                    </div>
                </div>
                <div class="container-fluid">
                    <div class="gallery-active owl-carousel">
                    	<?php 
                        $args = new \WP_Query(array(   
                        	'post_type' => 'gallery', 
                        ));  
                        while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
                    	$gallery_title = get_post_meta(get_the_ID(),'_cmb_gallery_title', true); 
                    	$gallery_subtitle = get_post_meta(get_the_ID(),'_cmb_gallery_subtitle', true); 
                    	?>
                        <div class="latest-gallery-wrapper">
                            <div class="latest-gallery-img">
                                <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt=""></a>
                                <div class="latest-gallery-text text-center">
                                    <p><?php echo htmlspecialchars_decode(esc_attr($gallery_subtitle));?></p>
                                    <h2><a href="<?php the_permalink();?>"><?php echo htmlspecialchars_decode(esc_attr($gallery_title));?></a></h2>
                                    <span></span>
                                </div>
                            </div>
                        </div>
                        <?php endwhile; ?>
                    </div>
                </div>
            </div>
<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           $('.gallery-active').owlCarousel({

		loop: true,

		nav: false,

		dots: false,

		margin:0,

		autoplay: true,

		navText: ['<i class="fas fa-angle-left"></i>', '<i class="fas fa-angle-right"></i>'],

		responsive: {

			0: {

				items: 1

			},

			576: {

				items: 1

			},

			768: {

				items: 3

			},

			992: {

				items: 4

			},

			1200: {

				items: 5

			}

		}

	})
        
        
    </script>   
    <?php } ?>
        <?php elseif( $chose_style == 'gallery_2' ): ?>
        	<div class="gallery-area pt-125 pb-130 fix">
               <div class="container">
                    <div class="row">
                        <div class="col-xl-6 offset-xl-3 col-lg-6 offset-lg-3">
                            <div class="upcoming-title upcoming-title-black text-center mb-80">
                                <?php if (( '' !== $settings['sub_heading_2'] ) && ( $settings['show_content'] )): ?>
                                <span><?php echo wp_kses_post($settings['sub_heading_2']); ?></span>
                                <?php endif; ?>	
                                <?php if (( '' !== $settings['heading_2'] ) && ( $settings['show_title'] )): ?>
                                <h1><?php echo wp_kses_post($settings['heading_2']); ?></h1>
                                <?php endif; ?>	
                            </div>
                        </div>
                    </div>
               </div>
                <div class="row no-gutters">
                    <div class="col-xl-6 col-lg-6">
                        <div class="gallery-wrapper">
                            <div class="gallery-img">
                            	<?php if (( '' !== $settings['image_2']['url'] ) && ( $settings['show_image'] )): ?>
                                <a href="<?php echo wp_kses_post($settings['link']); ?>"><img src="<?php echo wp_kses_post($settings['image_2']['url']); ?>" alt=""></a>
                                <?php endif; ?>
                                <div class="gallery-content text-center">
                                    <span></span>
                                    <?php if ( '' !== $settings['title_2'] ) : ?>
                                    <h1><a href="<?php echo wp_kses_post($settings['link']); ?>"><?php echo wp_kses_post($settings['title_2']); ?></a></h1>   
                                    <?php endif; ?>
                                    <?php if (( '' !== $settings['button'] ) && ( $settings['show_button'] )) : ?>
                                    <a class="btn" href="<?php echo wp_kses_post($settings['link']); ?>"><span class="btn-text"><?php echo wp_kses_post($settings['button']); ?></span> <span class="btn-border"></span></a>   
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-xl-6 col-lg-6">
                        <div class="row no-gutters">
                        	<div class="col-xl-6 col-lg-6">
                        		<?php 
                        		foreach ( $settings['tabs1'] as $item ) : ?>
                        			<div class="gallery-wrapper">
                        				<div class="gallery-img">
                        					<?php if (( '' !== $item['tab_image']['url'] ) && ( $settings['show_image'] )): ?>
                        					<a href="<?php echo wp_kses_post($item['link']); ?>"><img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt=""></a>
                        				<?php endif; ?>	
                        				<div class="gallery-video">
                        					<?php if ( '' !== $item['video_link'] ) : ?>
                        						<a class="popup-video" href="<?php echo wp_kses_post($item['video_link']); ?>"><i class="far fa-play"></i></a>
                        					<?php endif; ?>	
                        				</div>
                        			</div>
                        		</div>
                        		<?php
                        	endforeach;
                        	?>
                        </div>
                            <div class="col-xl-6 col-lg-6">
                            	<?php 
                        		foreach ( $settings['tabs2'] as $item ) : ?>
                                <div class="gallery-wrapper">
                        				<div class="gallery-img">
                        					<?php if (( '' !== $item['tab_image']['url'] ) && ( $settings['show_image'] )): ?>
                        					<a href="<?php echo wp_kses_post($item['link']); ?>"><img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt=""></a>
                        				<?php endif; ?>	
                        				<div class="gallery-video">
                        					<?php if ( '' !== $item['video_link'] ) : ?>
                        						<a class="popup-video" href="<?php echo wp_kses_post($item['video_link']); ?>"><i class="far fa-play"></i></a>
                        					<?php endif; ?>	
                        				</div>
                        			</div>
                        		</div>
                        		<?php
                        	endforeach;
                        	?>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="row no-gutters">
                    <div class="col-xl-4 col-lg-4">
                    	<?php 
                        		foreach ( $settings['tabs3'] as $item ) : ?>
                        			<div class="gallery-wrapper">
                        				<div class="gallery-img">
                        					<?php if (( '' !== $item['tab_image']['url'] ) && ( $settings['show_image'] )): ?>
                        					<a href="<?php echo wp_kses_post($item['link']); ?>"><img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt=""></a>
                        				<?php endif; ?>	
                        				<div class="gallery-video">
                        					<?php if ( '' !== $item['video_link'] ) : ?>
                        						<a class="popup-video" href="<?php echo wp_kses_post($item['video_link']); ?>"><i class="far fa-play"></i></a>
                        					<?php endif; ?>	
                        				</div>
                        			</div>
                        		</div>
                        <?php
                        	endforeach;
                        	?>
                    </div> 
                    <div class="col-xl-8 col-lg-8">
                    	<?php 
                        		foreach ( $settings['tabs4'] as $item ) : ?>
                        			<div class="gallery-wrapper">
                        				<div class="gallery-img">
                        					<?php if (( '' !== $item['tab_image']['url'] ) && ( $settings['show_image'] )): ?>
                        					<a href="<?php echo wp_kses_post($item['link']); ?>"><img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt=""></a>
                        				<?php endif; ?>	
                        				<div class="gallery-video">
                        					<?php if ( '' !== $item['video_link'] ) : ?>
                        						<a class="popup-video" href="<?php echo wp_kses_post($item['video_link']); ?>"><i class="far fa-play"></i></a>
                        					<?php endif; ?>	
                        				</div>
                        			</div>
                        		</div>
                        <?php
                        	endforeach;
                        	?>
                    </div>
                </div>
            </div>
        </div>
    <?php elseif( $chose_style == 'gallery_3' ): ?>
    	<div class="gallery-carousel-area pt-125 pb-175">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-6 offset-xl-3 col-lg-6 offset-lg-3">
                            <div class="upcoming-title upcoming-title-black text-center mb-80">
                                <?php if (( '' !== $settings['sub_heading_3'] ) && ( $settings['show_content'] )): ?>
                                <span><?php echo wp_kses_post($settings['sub_heading_3']); ?></span>
                                <?php endif; ?>	
                                <?php if (( '' !== $settings['heading_3'] ) && ( $settings['show_title'] )): ?>
                                <h1><?php echo wp_kses_post($settings['heading_3']); ?></h1>
                                <?php endif; ?>	
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="gallery-2-active owl-carousel">
                        	<?php 
                        		foreach ( $settings['tabs5'] as $item ) : ?>
                            <div class="col-xl-12">
                                <div class="gallery-wrapper">
                                    <div class="gallery-carousel-img">
                                    	<?php if (( '' !== $item['tab_image']['url'] ) && ( $settings['show_image'] )): ?>
                                        <img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt="">
                                        <?php endif; ?>	
                                        <?php if ( '' !== $item['video_link'] ) : ?>
                                        <div class="gallery-video gallery-2-video">
                                            <a class="popup-video" href="<?php echo wp_kses_post($item['video_link']); ?>"><i class="far fa-play"></i></a>
                                        </div>
                                        <?php endif; ?>	
                                    </div>
                                </div>
                            </div>
                            <?php
                        	endforeach;
                        	?>
                        </div>
                    </div>
                </div>
            </div>
<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
          $('.gallery-2-active').owlCarousel({

		loop: true,

		nav: true,

		dots: true,

		margin:0,

		autoplay: false,

		navText: ['<i class="far fa-long-arrow-alt-left"></i>', '<i class="far fa-long-arrow-alt-right"></i>'],

		responsive: {

			0: {

				items: 1,

				nav: false,

				dots: false,

			},

			576: {

				items: 1

			},

			768: {

				items: 1

			},

			992: {

				items: 1

			},

			1200: {

				items: 1

			}

		}

	})
        
        
    </script>   
    <?php } ?>
    <?php endif; ?>	
	<?php
	}

}
