<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsSlider extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-slider';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Slider', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-slideshow';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'slides', 'carousel' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_sliders',
			[
				'label' => esc_html__( 'Sliders', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'slider_home_1'  => esc_html__( 'Slider Home 1', 'bdevs-elementor' ),
					'slider_home_2' => esc_html__( 'Slider Home 2', 'bdevs-elementor' ),
					'slider_home_3' => esc_html__( 'Slider Home 3', 'bdevs-elementor' ),
				],
				'default'   => 'slider_home_1',
			]
		);

		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Slider Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Slide #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [
					[
						'name'        => 'tab_sub_title',
						'label'       => esc_html__( 'Sub Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Enjoy Your Life With Joy & Party' , 'bdevs-elementor' ),
						'label_block' => true,
					],					
					[
						'name'        => 'tab_title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'NIght Party' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_button',
						'label'       => esc_html__( 'Button', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Book Ticket' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],
					[
						'name'       => 'tab_content',
						'label'      => esc_html__( 'Content', 'bdevs-elementor' ),
						'type'       => Controls_Manager::TEXTAREA,
						'dynamic'    => [ 'active' => true ],
						'default'    => esc_html__( 'Slide Content', 'bdevs-elementor' ),
						'show_label' => false,
						'condition' => [
							'chose_style' => ['slider_default']
						],
					],
					[
						'name'        => 'tab_link',
						'label'       => esc_html__( 'Link Button', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Link' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_heading',
			[
				'label' => esc_html__( 'Slider Home 2', 'bdevs-elementor' ),
				
			]
		);
		$this->add_control(
			'image_1',
			[
				'label'       => __( 'Image 1', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Image 1', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		$this->add_control(
			'image_2',
			[
				'label'       => __( 'Image 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Image 2', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		
		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_heading',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Sub Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'link',
			[
				'label'       => __( 'Link Button 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Link Button 1', 'bdevs-elementor' ),
				'default'     => __( 'It is Link Button 1', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'button_1',
			[
				'label'       => __( 'Button 1', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Button 1', 'bdevs-elementor' ),
				'default'     => __( 'It is Button 1', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'video_link',
			[
				'label'       => __( 'Video Link', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Video Link', 'bdevs-elementor' ),
				'default'     => __( 'It is Video Link', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);

		$this->add_control(
			'button_2',
			[
				'label'       => __( 'Button 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Button 2', 'bdevs-elementor' ),
				'default'     => __( 'It is Button 2', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_heading_3',
			[
				'label' => esc_html__( 'Slider Home 3', 'bdevs-elementor' ),
				
			]
		);
		$this->add_control(
			'tabs_3',
			[
				'label' => esc_html__( 'Pricing Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Pricing #1', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'I am item content. Click edit button to change this text.', 'bdevs-elementor' ),
					]
				],
				'fields' => [	
					[
						'name'    => 'tab_image_home_3',
						'label'   => esc_html__( 'Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],			
					[
						'name'        => 'tab_title_home_3',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Title' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_subtitle_home_3',
						'label'       => esc_html__( 'Subtitle', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXTAREA,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Subtitle' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_link_home_3',
						'label'       => esc_html__( 'Link', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Link' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_button_home_3',
						'label'       => esc_html__( 'Button', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Button' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);
		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->add_control(
			'show_sub_title',
			[
				'label'   => esc_html__( 'Show Sub Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->add_control(
			'show_heading',
			[
				'label'   => esc_html__( 'Show Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->add_control(
			'show_sub_heading',
			[
				'label'   => esc_html__( 'Show Sub Heading', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_button_2',
			[
				'label'   => esc_html__( 'Show Button 2', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

		

		$this->start_controls_section(
			'section_content_button',
			[
				'label'     => esc_html__( 'Button', 'bdevs-elementor' ),
				'condition' => [
					'show_button' => 'yes',
				],
			]
		);

		$this->add_control(
			'button_text',
			[
				'label'       => esc_html__( 'Button Text', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Make Appointment', 'bdevs-elementor' ),
				'placeholder' => esc_html__( 'Make Appointment', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'icon',
			[
				'label'       => esc_html__( 'Icon Name Left', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'fas fa-play', 'bdevs-elementor' ),
				'placeholder' => esc_html__( 'Fontawesome Icon Fonts', 'bdevs-elementor' ),
			]
		);



		$this->end_controls_section();

	}

	public function render() {

		$settings  = $this->get_settings_for_display();
		$chose_style = $settings['chose_style'];
		?>

		<?php if( $chose_style == 'slider_home_1' ): ?>
			<div class="slider-area">
				<div class="slider-active">

					<?php $counter = 1; ?>
					<?php foreach ( $settings['tabs'] as $item ) : ?>
				
						<div class="single-slider slider-height d-flex align-items-center"
						style="background-image:url(<?php echo wp_kses_post($item['tab_image']['url']); ?>)">
						<div class="container">
							<div class="row ">
								<div class="col-xl-12">
									<div class="slider-content text-center">
										<?php if (( '' !== $item['tab_sub_title'] ) && ( $settings['show_sub_title'] )) : ?>
										<span data-animation="fadeInUp" data-delay=".3s"><?php echo wp_kses_post($item['tab_sub_title']); ?></span>
										<?php endif; ?>		

										<?php if (( '' !== $item['tab_title'] ) && ( $settings['show_title'] )) : ?>
										<h1 data-animation="fadeInLeft" data-delay=".5s"><?php echo wp_kses_post($item['tab_title']); ?></h1>
										<?php endif; ?>

										<?php if (( ! empty( $item['tab_link'] )) && ( $settings['show_button'] )): ?>
										<div class="slider-button" data-animation="fadeInUp" data-delay=".7s">
											<a class="btn" href="<?php echo wp_kses_post($item['tab_link']); ?>"><span class="btn-text"><?php echo wp_kses_post($item['tab_button']); ?></span> <span class="btn-border"></span></a>
										</div>
										<?php endif; ?>
									</div>
								</div>
							</div>
						</div>
					</div>
					<?php
					$counter++;
				endforeach;
				?>
			</div>
		</div>
		
       <?php elseif( $chose_style == 'slider_home_2' ): ?>
        <!-- hero-area start -->
        <div class="slider-area">
            <div class="slider-active">
            	<?php if (( '' !== $settings['image_1']['url'] ) && ( $settings['show_image'] )): ?>
                <div class="single-slider slider-1-height d-flex align-items-center"
                style="background-image:url(<?php echo wp_kses_post($settings['image_1']['url']); ?>)">
                <?php endif; ?>	
                <div class="container">
                    <div class="row ">
                    	<?php if ( '' !== $settings['image_2']['url'] ): ?>
                        <div class="slider-img d-none d-xl-block" data-animation="fadeInRight" data-delay="1.1s">
                            <img src="<?php echo wp_kses_post($settings['image_2']['url']); ?>" alt="">
                        </div>
                    	<?php endif; ?>
                        <div class="col-xl-8 col-lg-12">
                            <div class="slider-text">
                            	<?php if (( '' !== $settings['heading'] ) && ( $settings['show_heading'] )): ?>
                                <h1 data-animation="fadeInUp" data-delay=".3s"><?php echo wp_kses_post($settings['heading']); ?></h1>
                                <?php endif; ?>	
                                <?php if (( '' !== $settings['sub_heading'] ) && ( $settings['show_sub_heading'] )): ?>
                                <p data-animation="fadeInUp" data-delay=".5s"><?php echo wp_kses_post($settings['sub_heading']); ?></p>
                                <?php endif; ?>
                                <div class="slider-button slider-2-button">

                                	<?php if (( '' !== $settings['button_1'] ) && ( $settings['show_button'] )): ?>
                                    <a class="btn" href="<?php echo wp_kses_post($settings['link']); ?>" data-animation="fadeInUp" data-delay=".7s"><span class="btn-text"><?php echo wp_kses_post($settings['button_1']); ?></span> <span class="btn-border"></span></a>
                                    <?php endif; ?>	

                                    <?php if (( '' !== $settings['button_2'] ) && ( $settings['show_button_2'] )): ?>
                                    <div class="slider-video" data-animation="fadeInUp" data-delay=".9s"> <a class="popup-video" href="<?php echo wp_kses_post($settings['video_link']); ?>"><i class="fas fa-play"></i></a> <span><?php echo wp_kses_post($settings['button_2']); ?></span></div>
                                    <?php endif; ?>	
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <?php elseif( $chose_style == 'slider_home_3' ): ?>
    	<div class="slider-area slider-2">
            <div class="slider-active">
                <?php foreach ( $settings['tabs_3'] as $item ) : ?>
                	<?php if (( '' !== $item['tab_image_home_3']['url'] ) && ( $settings['show_image'] )): ?>
                <div class="single-slider slider-2-height d-flex align-items-center"
                    style="background-image:url(<?php echo wp_kses_post($item['tab_image_home_3']['url']); ?>)">
                    <?php endif; ?>
                    <div class="container">
                        <div class="row ">
                            <div class="col-xl-12">
                                <div class="slider-2-text text-center">
                                	<?php if (( '' !== $item['tab_title_home_3'] ) && ( $settings['show_heading'] )): ?>
                                    <h1 data-animation="fadeInUp" data-delay=".3s"><?php echo wp_kses_post($item['tab_title_home_3']); ?></h1>
                                    <?php endif; ?>
                                    <?php if (( '' !== $item['tab_subtitle_home_3'] ) && ( $settings['show_sub_heading'] )): ?>
                                    <p data-animation="fadeInUp" data-delay=".5s"><?php echo wp_kses_post($item['tab_subtitle_home_3']); ?></p>
                                    <?php endif; ?>
                                    <?php if (( '' !== $item['tab_button_home_3'] ) && ( $settings['show_button'] )): ?>
                                    <div class="slider-button" data-animation="fadeInUp" data-delay=".7s">
                                        <a class="btn pink-btn" href="<?php echo wp_kses_post($item['tab_link_home_3']); ?>"><span class="btn-text"><?php echo wp_kses_post($item['tab_button_home_3']); ?></span> <span class="btn-border"></span></a>
                                    </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            	<?php endforeach; ?>
            </div>
        </div>   
       <?php endif; ?>	
<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           function mainSlider() {

		var BasicSlider = $('.slider-active');

		BasicSlider.on('init', function (e, slick) {

			var $firstAnimatingElements = $('.single-slider:first-child').find('[data-animation]');

			doAnimations($firstAnimatingElements);

		});

		BasicSlider.on('beforeChange', function (e, slick, currentSlide, nextSlide) {

			var $animatingElements = $('.single-slider[data-slick-index="' + nextSlide + '"]').find('[data-animation]');

			doAnimations($animatingElements);

		});

		BasicSlider.slick({

			autoplay: false,

			autoplaySpeed: 10000,

			dots: false,

			fade: true,

			prevArrow: '<button type="button" class="slick-prev"> <i class="far fa-chevron-left"></i> </button>',

			nextArrow: '<button type="button" class="slick-next"> <i class="far fa-chevron-right"></i> </button>',

			arrows: true,

			responsive: [

				{ breakpoint: 767, settings: { dots: false, arrows: false } }

			]

		});



		function doAnimations(elements) {

			var animationEndEvents = 'webkitAnimationEnd mozAnimationEnd MSAnimationEnd oanimationend animationend';

			elements.each(function () {

				var $this = $(this);

				var $animationDelay = $this.data('delay');

				var $animationType = 'animated ' + $this.data('animation');

				$this.css({

					'animation-delay': $animationDelay,

					'-webkit-animation-delay': $animationDelay

				});

				$this.addClass($animationType).one(animationEndEvents, function () {

					$this.removeClass($animationType);

				});

			});

		}

	}

	mainSlider();
        
        
    </script>   
    <?php } ?>
	<?php
	}

}
