<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsTeam extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-team';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Team Area', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'team' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_Team',
			[
				'label' => esc_html__( 'Team', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'team_home_1'  => esc_html__( 'Team Home 1', 'bdevs-elementor' ),
					'team_home_2' => esc_html__( 'Team Home 2', 'bdevs-elementor' ),
					'team_home_3' => esc_html__( 'Team Home 3', 'bdevs-elementor' ),
					'team_about' => esc_html__( 'Team About', 'bdevs-elementor' ),
					'team_member' => esc_html__( 'Team Member', 'bdevs-elementor' ),
				],
				'default'   => 'team_home_1',
			]
		);


		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_heading',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Sub Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'content',
			[
				'label'       => __( 'Content', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXTAREA,
				'placeholder' => __( 'Enter your Content', 'bdevs-elementor' ),
				'default'     => __( 'It is Content', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'link',
			[
				'label'       => __( 'Link', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your link', 'bdevs-elementor' ),
				'default'     => __( 'It is Link', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'button',
			[
				'label'       => __( 'Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your button', 'bdevs-elementor' ),
				'default'     => __( 'It is Button', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);


		$this->add_control(
			'tabs',
			[
				'label' => esc_html__( 'Team Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Team One', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Team Two', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Support Content Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Team Three', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
				],
				'fields' => [	
				    [
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Team Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],
					[
						'name'        => 'tab_heading',
						'label'       => esc_html__( 'Heading', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Heading' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'tab_sub_heading',
						'label'       => esc_html__( 'Sub Heading', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Sub Heading' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_link1',
						'label'       => esc_html__( 'Link 1', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
					],
					[
						'name'        => 'tab_link2',
						'label'       => esc_html__( 'Link 2', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
					],
					[
						'name'        => 'tab_link3',
						'label'       => esc_html__( 'Link 3', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
					],
					[
						'name'        => 'tab_link4',
						'label'       => esc_html__( 'Link 4', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( '#' , 'bdevs-elementor' ),
					],
				],
			]
		);

		$this->end_controls_section();


		$this->start_controls_section(
			'section_content_team_2',
			[
				'label' => esc_html__( 'Team Home 2', 'bdevs-elementor' ),
				
			]
		);
		$this->add_control(
			'tabs2',
			[
				'label' => esc_html__( 'Team Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Team One', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Team Two', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Support Content Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Team Three', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
				],
				'fields' => [	
				    [
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Team Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],			
					
					[
						'name'        => 'tab_title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Heading' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'tab_subtitle',
						'label'       => esc_html__( 'Subtitle', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Subtitle' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_facebook',
						'label'       => esc_html__( 'Tab Facebook', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Facebook' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_twitter',
						'label'       => esc_html__( 'Tab Twitter', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Twitter' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_instagram',
						'label'       => esc_html__( 'Tab Instagram', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Instagram' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_vimeo',
						'label'       => esc_html__( 'Tab Vimeo', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Vimeo' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_team_3',
			[
				'label' => esc_html__( 'Team Home 3', 'bdevs-elementor' ),
				
			]
		);
		$this->add_control(
			'tabs3',
			[
				'label' => esc_html__( 'Team Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Team One', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Team Two', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Support Content Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Team Three', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
				],
				'fields' => [	
				    [
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Team Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],			
					
					[
						'name'        => 'tab_title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Heading' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'tab_subtitle',
						'label'       => esc_html__( 'Subtitle', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Subtitle' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_facebook',
						'label'       => esc_html__( 'Tab Facebook', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Facebook' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_twitter',
						'label'       => esc_html__( 'Tab Twitter', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Twitter' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_instagram',
						'label'       => esc_html__( 'Tab Instagram', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Instagram' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_vimeo',
						'label'       => esc_html__( 'Tab Vimeo', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Vimeo' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();




		$this->start_controls_section(
			'section_content_team_4',
			[
				'label' => esc_html__( 'Team About', 'bdevs-elementor' ),
				
			]
		);


		$this->add_control(
			'heading_about',
			[
				'label'       => __( 'Heading About', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading about', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading About', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	



		$this->add_control(
			'tabs_4',
			[
				'label' => esc_html__( 'Team Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Team One', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Team Two', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Support Content Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Team Three', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
				],
				'fields' => [	
				    [
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Team Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],			
					
					[
						'name'        => 'tab_title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Heading' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'tab_subtitle',
						'label'       => esc_html__( 'Subtitle', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Subtitle' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_facebook',
						'label'       => esc_html__( 'Tab Facebook', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Facebook' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_twitter',
						'label'       => esc_html__( 'Tab Twitter', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Twitter' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_instagram',
						'label'       => esc_html__( 'Tab Instagram', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Instagram' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_vimeo',
						'label'       => esc_html__( 'Tab Vimeo', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Vimeo' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_team_5',
			[
				'label' => esc_html__( 'Team Member', 'bdevs-elementor' ),
				
			]
		);


		$this->add_control(
			'button_member',
			[
				'label'       => __( 'Button Member', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Button Member', 'bdevs-elementor' ),
				'default'     => __( 'It is Button Member', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	


		$this->add_control(
			'link_member',
			[
				'label'       => __( 'Link Member', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Link Member', 'bdevs-elementor' ),
				'default'     => __( 'It is Link Member', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	



		$this->add_control(
			'tabs_5',
			[
				'label' => esc_html__( 'Team Items', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Team One', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Team Two', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Support Content Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Team Three', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
				],
				'fields' => [	
				    [
						'name'    => 'tab_image',
						'label'   => esc_html__( 'Team Image', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],			
					
					[
						'name'        => 'tab_title',
						'label'       => esc_html__( 'Title', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Heading' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'tab_subtitle',
						'label'       => esc_html__( 'Subtitle', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Subtitle' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_facebook',
						'label'       => esc_html__( 'Tab Facebook', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Facebook' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_twitter',
						'label'       => esc_html__( 'Tab Twitter', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Twitter' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_instagram',
						'label'       => esc_html__( 'Tab Instagram', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Instagram' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_vimeo',
						'label'       => esc_html__( 'Tab Vimeo', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Vimeo' , 'bdevs-elementor' ),
						'label_block' => true,
					],
				],
			]
		);

		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_subtitle',
			[
				'label'   => esc_html__( 'Show Subtitle', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);	

		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

		
	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		$chose_style = $settings['chose_style'];
		?>
		<?php if( $chose_style == 'team_home_1' ): ?>
		<div class="team-area team-padding pt-180 pb-100 pl-135 pr-135">
                <div class="container">
                <div class="row">
                        <div class="col-xl-8 col-lg-8">
                            <div class="section-title section-title-left mb-85">
                            	<?php if ( '' !== $settings['heading'] ): ?>
                                <h1><?php echo wp_kses_post($settings['heading']); ?></h1>
								<?php endif; ?>
                            	<?php if ( '' !== $settings['sub_heading'] ): ?>
                                <h2><?php echo wp_kses_post($settings['sub_heading']); ?></h2>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="container-fluid">
                    <div class="row">
                        <div class="team-active owl-carousel">
                        	<?php 
							foreach ( $settings['tabs'] as $item ) : ?>

                            <div class="col-xl-12">
                                <div class="team-wrapper">
                                	<?php if (( '' !== $item['tab_image']['url'] ) && ( $settings['show_image'] )): ?>
                                    <div class="team-img">
                                        <img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt="">
										<div class="team-icon">
                                            <a href="<?php echo wp_kses_post($item['tab_link1']); ?>"><i class="fab fa-facebook-f"></i></a>
                                            <a href="<?php echo wp_kses_post($item['tab_link2']); ?>"><i class="fab fa-twitter"></i></a>
                                            <a href="<?php echo wp_kses_post($item['tab_link3']); ?>"><i class="fab fa-instagram"></i></a>
                                            <a href="<?php echo wp_kses_post($item['tab_link4']); ?>"><i class="fab fa-vimeo-v"></i></a>
                                        </div>
                                    </div>
                                    <?php endif; ?>	
                                    <div class="team-text text-center">
                                        <?php if (( '' !== $item['tab_heading'] ) && ( $settings['show_title'] )): ?>
                                        <h2><?php echo wp_kses_post($item['tab_heading']); ?></h2>
                                        <?php endif; ?>
                                        <?php if (( '' !== $item['tab_sub_heading'] ) && ( $settings['show_subtitle'] )) : ?>
                                        <span><?php echo wp_kses_post($item['tab_sub_heading']); ?></span>
                                        <?php endif; ?>	
                                    </div>
                                </div>
                            </div>

                            <?php
							endforeach;
							?>
                        </div>
                    </div>
                </div>
            </div>
<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           $('.team-active').owlCarousel({

		loop: true,

		nav: true,

		dots: false,

		// autoplay: true,

		navText: ['<i class="far fa-angle-left"></i>', '<i class="far fa-angle-right"></i>'],

		responsive: {

			0: {

				items: 1,

				nav: false,

			},

			576: {

				items: 1,

				nav: false,

			},

			768: {

				items: 2,

				nav: false,

			},

			992: {

				items: 3

			},

			1200: {

				items: 4

			}

		}

	})
        
        
    </script>   
    <?php } ?>
        <?php elseif( $chose_style == 'team_home_2' ): ?>
        	<div class="team-area pt-130 pb-50">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-4 col-lg-4 col-md-6 col-sm-6">
                            <div class="area-title pb-80">
                                <span></span>
                                <?php if ( '' !== $settings['heading'] )  : ?>
                                <h1><?php echo wp_kses_post($settings['heading']); ?></h1>
                                <?php endif; ?>
                                <?php if ( '' !== $settings['sub_heading'] )  : ?>
                                <p><?php echo wp_kses_post($settings['sub_heading']); ?></p>
                                <?php endif; ?>
                                <div class="team-title">
                                    <?php if ( '' !== $settings['content'] )  : ?>
                                <p><?php echo wp_kses_post($settings['content']); ?></p>
                                <?php endif; ?>
                                <?php if (( '' !== $settings['button'] ) && ( $settings['show_button'] )) : ?>
                                    <a class="btn" href="<?php echo wp_kses_post($settings['link']); ?>"><span class="btn-text"><?php echo wp_kses_post($settings['button']); ?></span> <span class="btn-border"></span></a>
                                <?php endif; ?>
                                </div>
                            </div>
                        </div>
                        <?php foreach ( $settings['tabs2'] as $item ) : ?>
                        <div class="col-xl-4 col-lg-4 col-md-6 col-sm-6">
                            <div class="team-wrapper mb-80">
                            	<?php if (( '' !== $item['tab_image']['url'] ) && ( $settings['show_image'] )) : ?>
                                <div class="team-img">
                                    <img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt="">
                                </div>
                            	<?php endif; ?>
                                <div class="team-text team-2-text text-center">
                                    <div class="team-icon">
                                    	<?php if ( '' !== $item['tab_facebook'] )  : ?>
                                        <a href="<?php echo wp_kses_post($item['tab_facebook']); ?>"><i class="fab fa-facebook-f"></i></a>
                                        <?php endif; ?>
                                        <?php if ( '' !== $item['tab_twitter'] )  : ?>
                                        <a href="<?php echo wp_kses_post($item['tab_twitter']); ?>"><i class="fab fa-twitter"></i></a>
                                        <?php endif; ?>
                                        <?php if ( '' !== $item['tab_instagram'] )  : ?>
                                        <a href="<?php echo wp_kses_post($item['tab_instagram']); ?>"><i class="fab fa-instagram"></i></a>
                                        <?php endif; ?>
                                        <?php if ( '' !== $item['tab_vimeo'] )  : ?>
                                        <a href="<?php echo wp_kses_post($item['tab_vimeo']); ?>"><i class="fab fa-vimeo-v"></i></a>
                                        <?php endif; ?>
                                    </div>
                                    <?php if (( '' !== $item['tab_title'] ) && ( $settings['show_title'] )) : ?>
                                    <h2><?php echo wp_kses_post($item['tab_title']); ?></h2>
                                    <?php endif; ?>		
                                    <?php if (( '' !== $item['tab_subtitle'] ) && ( $settings['show_subtitle'] )) : ?>
                                    <span><?php echo wp_kses_post($item['tab_subtitle']); ?></span>
                                    <?php endif; ?>	
                                </div>
                            </div>
                        </div>
                        <?php
                    endforeach;
                    ?>
                    </div>
                </div>
            </div>
        <?php elseif( $chose_style == 'team_home_3' ): ?>
        	<div class="team-2-area pl-20 pr-20 pt-130 pb-130 dark-soft">
                <div class="container-fluid">
                    <div class="team-2-active owl-carousel">
						<?php foreach ( $settings['tabs3'] as $item ) : ?>
                        <div class="team-wrapper">
                        	<?php if (( '' !== $item['tab_image']['url'] ) && ( $settings['show_image'] )) : ?>
	                        	<div class="team-img">
	                        		<img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt="">
	                        	</div>
	                        <?php endif; ?>
                            <div class="team-text team-3-text text-center">
                                <div class="team-icon">
                                	<?php if ( '' !== $item['tab_facebook'] )  : ?>
                                		<a href="<?php echo wp_kses_post($item['tab_facebook']); ?>"><i class="fab fa-facebook-f"></i></a>
                                	<?php endif; ?>
                                	<?php if ( '' !== $item['tab_twitter'] )  : ?>
                                		<a href="<?php echo wp_kses_post($item['tab_twitter']); ?>"><i class="fab fa-twitter"></i></a>
                                	<?php endif; ?>
                                	<?php if ( '' !== $item['tab_instagram'] )  : ?>
                                		<a href="<?php echo wp_kses_post($item['tab_instagram']); ?>"><i class="fab fa-instagram"></i></a>
                                	<?php endif; ?>
                                	<?php if ( '' !== $item['tab_vimeo'] )  : ?>
                                		<a href="<?php echo wp_kses_post($item['tab_vimeo']); ?>"><i class="fab fa-vimeo-v"></i></a>
                                	<?php endif; ?>
                                </div>
                                <?php if (( '' !== $item['tab_title'] ) && ( $settings['show_title'] )) : ?>
                                    <h2><?php echo wp_kses_post($item['tab_title']); ?></h2>
                                    <?php endif; ?>		
                                    <?php if (( '' !== $item['tab_subtitle'] ) && ( $settings['show_subtitle'] )) : ?>
                                    <span><?php echo wp_kses_post($item['tab_subtitle']); ?></span>
                                    <?php endif; ?>	
                            </div>
                        </div>
                        <?php
                    endforeach;
                    ?>
                    </div>
                </div>
            </div>
<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           $('.team-2-active').owlCarousel({

		loop: true,

		nav: false,

		dots: false,

		margin:0,

		autoplay: false,

		navText: ['<i class="fas fa-angle-left"></i>', '<i class="fas fa-angle-right"></i>'],

		responsive: {

			0: {

				items: 1

			},

			576: {

				items: 1

			},

			768: {

				items: 2

			},

			992: {

				items: 3

			},

			1200: {

				items: 5

			}

		}

	})
        
        
    </script>   
    <?php } ?>
		<?php elseif( $chose_style == 'team_about' ): ?>
			<div class="team-2-area pl-20 pr-20 pb-150">
                <div class="container">
                    <div class="row">
                        <div class="col-xl-6 col-lg-6 offset-lg-3 offset-xl-3">
                            <div class="section-title section-2-title text-center mb-70">
                               <?php if (( '' !== $settings['heading_about'] ) && ( $settings['show_title'] )): ?>
                                <h2><?php echo wp_kses_post($settings['heading_about']); ?></h2>
								<?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="container-fluid">
                    <div class="team-2-active owl-carousel">
                    	<?php foreach ( $settings['tabs_4'] as $item ) : ?>
                        <div class="team-wrapper mb-30">
                            <?php if (( '' !== $item['tab_image']['url'] ) && ( $settings['show_image'] )) : ?>
	                        	<div class="team-img">
	                        		<img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt="">
	                        	</div>
	                        <?php endif; ?>
                            <div class="team-text team-3-text team-4-text text-center">
                                <div class="team-icon">
                                	<?php if ( '' !== $item['tab_facebook'] )  : ?>
                                		<a href="<?php echo wp_kses_post($item['tab_facebook']); ?>"><i class="fab fa-facebook-f"></i></a>
                                	<?php endif; ?>
                                	<?php if ( '' !== $item['tab_twitter'] )  : ?>
                                		<a href="<?php echo wp_kses_post($item['tab_twitter']); ?>"><i class="fab fa-twitter"></i></a>
                                	<?php endif; ?>
                                	<?php if ( '' !== $item['tab_instagram'] )  : ?>
                                		<a href="<?php echo wp_kses_post($item['tab_instagram']); ?>"><i class="fab fa-instagram"></i></a>
                                	<?php endif; ?>
                                	<?php if ( '' !== $item['tab_vimeo'] )  : ?>
                                		<a href="<?php echo wp_kses_post($item['tab_vimeo']); ?>"><i class="fab fa-vimeo-v"></i></a>
                                	<?php endif; ?>
                                </div>
                                <?php if (( '' !== $item['tab_title'] ) && ( $settings['show_title'] )) : ?>
                                    <h2><?php echo wp_kses_post($item['tab_title']); ?></h2>
                                <?php endif; ?>		
                                <?php if (( '' !== $item['tab_subtitle'] ) && ( $settings['show_subtitle'] )) : ?>
                                    <span><?php echo wp_kses_post($item['tab_subtitle']); ?></span>
                                <?php endif; ?>	
                            </div>
                        </div>
                        <?php
                    endforeach;
                    ?>
                    </div>
                </div>
            </div>
		<?php elseif( $chose_style == 'team_member' ): ?>
			<div class="team-area pt-130 pb-130">
                <div class="container">
                    <div class="row">
						<?php foreach ( $settings['tabs_5'] as $item ) : ?>
                        <div class="col-xl-4 col-lg-4 col-md-6">
                            <div class="team-wrapper mb-80">
                            	<?php if (( '' !== $item['tab_image']['url'] ) && ( $settings['show_image'] )) : ?>
                                <div class="team-img">
                                    <img src="<?php echo wp_kses_post($item['tab_image']['url']); ?>" alt="">
                                </div>
                                <?php endif; ?>
                                <div class="team-text team-2-text text-center">
                                    <div class="team-icon">
	                                	<?php if ( '' !== $item['tab_facebook'] )  : ?>
	                                		<a href="<?php echo wp_kses_post($item['tab_facebook']); ?>"><i class="fab fa-facebook-f"></i></a>
	                                	<?php endif; ?>
	                                	<?php if ( '' !== $item['tab_twitter'] )  : ?>
	                                		<a href="<?php echo wp_kses_post($item['tab_twitter']); ?>"><i class="fab fa-twitter"></i></a>
	                                	<?php endif; ?>
	                                	<?php if ( '' !== $item['tab_instagram'] )  : ?>
	                                		<a href="<?php echo wp_kses_post($item['tab_instagram']); ?>"><i class="fab fa-instagram"></i></a>
	                                	<?php endif; ?>
	                                	<?php if ( '' !== $item['tab_vimeo'] )  : ?>
	                                		<a href="<?php echo wp_kses_post($item['tab_vimeo']); ?>"><i class="fab fa-vimeo-v"></i></a>
	                                	<?php endif; ?>
	                                </div>
                                    <?php if (( '' !== $item['tab_title'] ) && ( $settings['show_title'] )) : ?>
	                                    <h2><?php echo wp_kses_post($item['tab_title']); ?></h2>
	                                <?php endif; ?>		
	                                <?php if (( '' !== $item['tab_subtitle'] ) && ( $settings['show_subtitle'] )) : ?>
	                                    <span><?php echo wp_kses_post($item['tab_subtitle']); ?></span>
	                                <?php endif; ?>	
                                </div>
                            </div>
                        </div>
                       <?php
                    endforeach;
                    ?>
                    </div>
                    <div class="row">
                        <div class="col-xl-12">
                        	<?php if (( '' !== $settings['button_member'] ) && ( $settings['show_button'] )) : ?>
                            <div class="event-list-button text-center">
                                <a class="btn" href="<?php echo wp_kses_post($settings['link_member']); ?>"><span class="btn-text"><?php echo wp_kses_post($settings['button_member']); ?></span> <span class="btn-border"></span></a>
                            </div>
                            <?php endif; ?>	
                        </div>
                    </div>
                </div>
            </div>
        <?php endif; ?>	
	<?php
	}

}