<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsTestimonial extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-testimonial';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Testimonial Area', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'testimonial' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_Testimonial',
			[
				'label' => esc_html__( 'Testimonial', 'bdevs-elementor' ),
			]
		);


		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_heading',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Sub Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	


		$this->add_control(
			'tabs1',
			[
				'label' => esc_html__( 'Testimonial Image', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Testimonial One', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Testimonial Two', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Support Content Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Testimonial Three', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
				],
				'fields' => [	
				    [
						'name'    => 'tab_image1',
						'label'   => esc_html__( 'Testimonial Image 1', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],	

					[
						'name'        => 'tab_class',
						'label'       => esc_html__( 'Class Image', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Class Image' , 'bdevs-elementor' ),
						'label_block' => true,
					],

				],
			]
		);


		

		$this->add_control(
			'tabs2',
			[
				'label' => esc_html__( 'Testimonial Image', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Testimonial One', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Testimonial Two', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Support Content Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Testimonial Three', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
				],
				'fields' => [	
				    [
						'name'    => 'tab_image2',
						'label'   => esc_html__( 'Testimonial Image 2', 'bdevs-elementor' ),
						'type'    => Controls_Manager::MEDIA,
						'dynamic' => [ 'active' => true ],
						'default'     => esc_html__( '' , 'bdevs-elementor' ),
					],	

				],
			]
		);

		$this->add_control(
			'tabs3',
			[
				'label' => esc_html__( 'Testimonial Content', 'bdevs-elementor' ),
				'type' => Controls_Manager::REPEATER,
				'default' => [
					[
						'tab_title'   => esc_html__( 'Testimonial One', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Testimonial Two', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Support Content Marketing', 'bdevs-elementor' ),
					],
					[
						'tab_title'   => esc_html__( 'Testimonial Three', 'bdevs-elementor' ),
						'tab_content' => esc_html__( 'Focus On Email Marketing', 'bdevs-elementor' ),
					],
				],
				'fields' => [		
					[
						'name'        => 'tab_heading',
						'label'       => esc_html__( 'Heading', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Heading' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'tab_sub_heading',
						'label'       => esc_html__( 'Sub Heading', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Sub Heading' , 'bdevs-elementor' ),
						'label_block' => true,
					],
					[
						'name'        => 'tab_author',
						'label'       => esc_html__( 'Author', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Author' , 'bdevs-elementor' ),
						'label_block' => true,
					],

					[
						'name'        => 'tab_job',
						'label'       => esc_html__( 'Job', 'bdevs-elementor' ),
						'type'        => Controls_Manager::TEXT,
						'dynamic'     => [ 'active' => true ],
						'default'     => esc_html__( 'Tab Job' , 'bdevs-elementor' ),
						'label_block' => true,
					],

				],
			]
		);

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->add_control(
			'show_content',
			[
				'label'   => esc_html__( 'Show Content', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

		

		$this->start_controls_section(
			'section_content_button',
			[
				'label'     => esc_html__( 'Button', 'bdevs-elementor' ),
				'condition' => [
					'show_button' => 'yes',
				],
			]
		);

		$this->add_control(
			'button_text',
			[
				'label'       => esc_html__( 'Button Text', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Read More', 'bdevs-elementor' ),
				'placeholder' => esc_html__( 'Read More', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'icon',
			[
				'label'       => esc_html__( 'Icon', 'bdevs-elementor' ),
				'type'        => Controls_Manager::ICON,
				'label_block' => true,
			]
		);

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();

		?>
		<div class="testimonial-area pt-180 pb-110 pos-rel">
                <div class="shape d-none d-xl-block">
                	<?php 
                	foreach ( $settings['tabs1'] as $item ) : ?>
                		<?php if (( '' !== $item['tab_image1']['url'] ) && ( $settings['show_image'] )): ?>
                		<div class="shape-item <?php echo wp_kses_post($item['tab_class']); ?>"><img src="<?php echo wp_kses_post($item['tab_image1']['url']); ?>" alt=""></div>
                	<?php endif; ?>	
                	<?php
                endforeach;
                ?>
                </div>
                <div class="container">
                    <div class="row">
                        <div class="col-xl-8 col-lg-8 offset-lg-2 offset-xl-2">
                            <div class="section-title text-center mb-65">
                                <h1><?php echo wp_kses_post($settings['heading']); ?></h1>
                                <h2><?php echo wp_kses_post($settings['sub_heading']); ?></h2>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-xl-10 offset-xl-1">
                            <div class="testimonial-nav">
                            	<?php 
							foreach ( $settings['tabs2'] as $item ) : ?>
								<?php if ( '' !== $item['tab_image2']['url'] ): ?>
                                <div class="testimonial-thumb">
                                    <img src="<?php echo wp_kses_post($item['tab_image2']['url']); ?>" alt="">
                                </div>
                                <?php endif; ?>	
                                <?php
                            endforeach;
                            ?>
                            </div>
                            <div class="testimonia-item-active">
								<?php 
								foreach ( $settings['tabs3'] as $item ) : ?>
                                <div class="testimonial-item text-center">
                                	<?php if (( '' !== $item['tab_heading'] ) && ( $settings['show_title'] )): ?>
                                    <h3><?php echo wp_kses_post($item['tab_heading']); ?></h3>
                                     <?php endif; ?>
                                     <?php if (( '' !== $item['tab_sub_heading'] ) && ( $settings['show_content'] )) : ?>
                                    <p><?php echo wp_kses_post($item['tab_sub_heading']); ?></p>
                                    <?php endif; ?>	
                                    <div class="designation">
                                        <h3><?php echo wp_kses_post($item['tab_author']); ?></h3>
                                        <span><?php echo wp_kses_post($item['tab_job']); ?></span>
                                    </div>
                                </div>
								<?php
                            endforeach;
                            ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
          $('.testimonia-item-active').slick({

		slidesToShow: 1,

		slidesToScroll: 1,

		dots: true,

		arrows: true,

		fade: true,

		prevArrow: '<button type="button" class="slick-prev"><i class="fas fa-chevron-left"></i></button>',

		nextArrow: '<button type="button" class="slick-next"><i class="fas fa-chevron-right"></i></button>',

		asNavFor: '.testimonial-nav',

		responsive: [

			{ 

				breakpoint: 992,

				 settings: {

					dots: false, arrows: false 

				} 

			}

		]

	});



	$('.testimonial-nav').slick({

		slidesToShow: 3,

		slidesToScroll: 1,

		asNavFor: '.testimonia-item-active',

		arrows: false,

		centerMode: true,

		focusOnSelect: true,

		centerPadding: 0,

		responsive: [

			{ 

				breakpoint: 992,

				 settings: {

					dots: false, arrows: false 

				} 

			}

		]

	});
        
        
    </script>   
    <?php } ?>
	<?php
	}

}