<?php
namespace BdevsElementor\Widget;

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Scheme_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

/**
 * Bdevs Elementor Widget.
 *
 * Elementor widget that inserts an embbedable content into the page, from any given URL.
 *
 * @since 1.0.0
 */
class BdevsUpcoming extends \Elementor\Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Bdevs Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'bdevs-upcoming';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Bdevs Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return __( 'Upcoming List', 'bdevs-elementor' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Bdevs Slider widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-favorite';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Bdevs Slider widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'bdevs-elementor' ];
	}

	public function get_keywords() {
		return [ 'upcoming' ];
	}

	public function get_script_depends() {
		return [ 'bdevs-elementor'];
	}

	// BDT Position
	protected function element_pack_position() {
	    $position_options = [
	        ''              => esc_html__('Default', 'bdevs-elementor'),
	        'top-left'      => esc_html__('Top Left', 'bdevs-elementor') ,
	        'top-center'    => esc_html__('Top Center', 'bdevs-elementor') ,
	        'top-right'     => esc_html__('Top Right', 'bdevs-elementor') ,
	        'center'        => esc_html__('Center', 'bdevs-elementor') ,
	        'center-left'   => esc_html__('Center Left', 'bdevs-elementor') ,
	        'center-right'  => esc_html__('Center Right', 'bdevs-elementor') ,
	        'bottom-left'   => esc_html__('Bottom Left', 'bdevs-elementor') ,
	        'bottom-center' => esc_html__('Bottom Center', 'bdevs-elementor') ,
	        'bottom-right'  => esc_html__('Bottom Right', 'bdevs-elementor') ,
	    ];

	    return $position_options;
	}

	protected function _register_controls() {
		$this->start_controls_section(
			'section_content_upcoming',
			[
				'label' => esc_html__( 'Upcoming', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'chose_style',
			[
				'label'     => esc_html__( 'Chose Style', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'upcoming_home_1'  => esc_html__( 'Upcoming Home 2', 'bdevs-elementor' ),
					'upcoming_home_3' => esc_html__( 'Upcoming Home 3', 'bdevs-elementor' ),
					'upcoming_style_4' => esc_html__( 'Upcoming Events', 'bdevs-elementor' ),
					'upcoming_style_5' => esc_html__( 'Upcoming Events 1', 'bdevs-elementor' ),
				],
				'default'   => 'upcoming_home_1',
			]
		);

		$this->add_control(
			'image',
			[
				'label'   => esc_html__( 'Events Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Events Image', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'heading',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_heading',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Sub Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	


		$this->add_control(
			'post_number',
			[
				'label'     => esc_html__( 'Post Count', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'3'  => esc_html__( '3', 'bdevs-elementor' ),
					'6' => esc_html__( '6', 'bdevs-elementor' ),
					'9' => esc_html__( '9', 'bdevs-elementor' ),
					'12' => esc_html__( '12', 'bdevs-elementor' ),
				],
				'default'   => '3',
			]
		);

		$this->add_control(
			'post_order',
			[
				'label'     => esc_html__( 'Post Order', 'bdevs-elementor' ),
				'type'      => Controls_Manager::SELECT,
				'options'   => [
					'asc'  => esc_html__( 'ASC', 'bdevs-elementor' ),
					'desc' => esc_html__( 'DESC', 'bdevs-elementor' ),
				],
				'default'   => 'desc',
			]
		);



		$this->end_controls_section();



		$this->start_controls_section(
			'section_content_upcoming_2',
			[
				'label' => esc_html__( 'Upcoming Home 3', 'bdevs-elementor' ),
				
			]
		);
		$this->add_control(
			'image_1_home_3',
			[
				'label'       => __( 'Image 1', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Image 1', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		$this->add_control(
			'image_2_home_3',
			[
				'label'       => __( 'Image 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Image 2', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		
		$this->add_control(
			'heading_home_3',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_heading_home_3',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Sub Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'content_home_3',
			[
				'label'       => __( 'Content', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your content', 'bdevs-elementor' ),
				'default'     => __( 'It is Content', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'showtime_home_3',
			[
				'label'       => __( 'Showtime', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your showtime', 'bdevs-elementor' ),
				'default'     => __( 'It is showtime', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'link_home_3',
			[
				'label'       => __( 'Link Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Link Button', 'bdevs-elementor' ),
				'default'     => __( 'It is Link Button', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'button_home_3',
			[
				'label'       => __( 'Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Button', 'bdevs-elementor' ),
				'default'     => __( 'It is Button', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->end_controls_section();

		$this->start_controls_section(
			'section_content_upcoming_3',
			[
				'label' => esc_html__( 'Upcoming Home 4', 'bdevs-elementor' ),
				
			]
		);
		$this->add_control(
			'image_1_event',
			[
				'label'       => __( 'Image 1', 'bdevs-elementor' ),
				'type'    => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Image 1', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);		

		$this->add_control(
			'image_2_event',
			[
				'label'       => __( 'Image 2', 'bdevs-elementor' ),
				'type'        => Controls_Manager::MEDIA,
				'dynamic' => [ 'active' => true ],
				'description' => esc_html__( 'Add Your Image 2', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	
		
		$this->add_control(
			'heading_event',
			[
				'label'       => __( 'Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'sub_event',
			[
				'label'       => __( 'Sub Heading', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your sub heading', 'bdevs-elementor' ),
				'default'     => __( 'It is Sub Heading', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	


		$this->add_control(
			'showtime_event',
			[
				'label'       => __( 'Showtime', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your showtime', 'bdevs-elementor' ),
				'default'     => __( 'It is showtime', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'link_event',
			[
				'label'       => __( 'Link Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Link Button', 'bdevs-elementor' ),
				'default'     => __( 'It is Link Button', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->add_control(
			'button_event',
			[
				'label'       => __( 'Button', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'placeholder' => __( 'Enter your Button', 'bdevs-elementor' ),
				'default'     => __( 'It is Button', 'bdevs-elementor' ),
				'label_block' => true,
			]
		);	

		$this->end_controls_section();


		$this->start_controls_section(
			'section_content_layout',
			[
				'label' => esc_html__( 'Layout', 'bdevs-elementor' ),
			]
		);

		$this->add_responsive_control(
			'align',
			[
				'label'   => esc_html__( 'Alignment', 'bdevs-elementor' ),
				'type'    => Controls_Manager::CHOOSE,
				'options' => [
					'left' => [
						'title' => esc_html__( 'Left', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-left',
					],
					'center' => [
						'title' => esc_html__( 'Center', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-center',
					],
					'right' => [
						'title' => esc_html__( 'Right', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-right',
					],
					'justify' => [
						'title' => esc_html__( 'Justified', 'bdevs-elementor' ),
						'icon'  => 'fa fa-align-justify',
					],
				],
				'prefix_class' => 'elementor%s-align-',
				'description'  => 'Use align to match position',
				'default'      => 'center',
			]
		);

		$this->add_control(
			'show_title',
			[
				'label'   => esc_html__( 'Show Title', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);		

		$this->add_control(
			'show_image',
			[
				'label'   => esc_html__( 'Show Image', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);


		$this->add_control(
			'show_content',
			[
				'label'   => esc_html__( 'Show Content', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->add_control(
			'show_button',
			[
				'label'   => esc_html__( 'Show Button', 'bdevs-elementor' ),
				'type'    => Controls_Manager::SWITCHER,
				'default' => 'yes',
			]
		);

		$this->end_controls_section();

		

		$this->start_controls_section(
			'section_content_button',
			[
				'label'     => esc_html__( 'Button', 'bdevs-elementor' ),
				'condition' => [
					'show_button' => 'yes',
				],
			]
		);

		$this->add_control(
			'button_text',
			[
				'label'       => esc_html__( 'Button Text', 'bdevs-elementor' ),
				'type'        => Controls_Manager::TEXT,
				'default'     => esc_html__( 'Read More', 'bdevs-elementor' ),
				'placeholder' => esc_html__( 'Read More', 'bdevs-elementor' ),
			]
		);

		$this->add_control(
			'icon',
			[
				'label'       => esc_html__( 'Icon', 'bdevs-elementor' ),
				'type'        => Controls_Manager::ICON,
				'label_block' => true,
			]
		);

		$this->end_controls_section();

	}

	public function render() {
		$settings  = $this->get_settings_for_display();
		$chose_style = $settings['chose_style'];
		$order = $settings['post_order'];
		$post_number = $settings['post_number'];

	    $wp_query = new \WP_Query(array('posts_per_page' => $post_number,'post_type' => 'events',  'orderby' => 'ID', 'order' => 'ASC'));
	    

	    //other style
	    $args = array('posts_per_page' => $post_number,'post_type' => 'events',  'orderby' => 'ID', 'order' => 'ASC');
		?>
		
		<?php if( $chose_style == 'upcoming_home_1' ): ?>
		<?php if (( '' !== $settings['image']['url'] ) && ( $settings['show_image'] )): ?>
			<div class="upcoming-area pt-120 pb-100" style="background-image:url(<?php echo wp_kses_post($settings['image']['url']); ?>)">
				<?php endif; ?>	
				<div class="container">
					<div class="row">
						<div class="col-xl-8 col-lg-8 offset-lg-2 offset-xl-2">
							 <?php if (( '' !== $settings['heading'] ) && ( $settings['show_title'] )): ?>
							<div class="area-title text-center pb-75">
								<span></span>
							<h1><?php echo wp_kses_post($settings['heading']); ?></h1>
							<?php endif; ?>	
                                <?php if (( '' !== $settings['sub_heading'] ) && ( $settings['show_content'] )): ?>
							<p><?php echo wp_kses_post($settings['sub_heading']); ?></p>
							</div>
							<?php endif; ?>	
						</div>
					</div>
            			<div class="row">
            				<?php 
            				$args = new \WP_Query(array(   
            					'post_type' => 'events', 
            				));  
            				$i = 1;
            				while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
            					$i++;

            					$events_time = get_post_meta(get_the_ID(),'_cmb_events_time', true); 
            					$events_date = get_post_meta(get_the_ID(),'_cmb_events_date', true); 
            					$events_user = get_post_meta(get_the_ID(),'_cmb_events_user', true); 
            					$events_price = get_post_meta(get_the_ID(),'_cmb_events_price', true); 
            					$events_excerpt = get_post_meta(get_the_ID(),'_cmb_events_excerpt', true); 
            					?>

            					<div class="col-xl-4 col-lg-6 col-md-6">
            						<div class="upcoming-event-wrapper mb-30">
            							<div class="upcoming-event-img">
            								<a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt=""></a>
            								<div class="up-tag">
            									<span><?php echo htmlspecialchars_decode(esc_attr($events_price));?></span>
            								</div>
            							</div>
            							<div class="upcoming-text">
            								<h3><a href="<?php the_permalink();?>"><?php the_title();?></a></h3>
            								<div class="up-event-meta">
            									<span> <i class="far fa-calendar-alt"></i> <?php echo htmlspecialchars_decode(esc_attr($events_date));?></span>
            									<span> <i class="far fa-clock"></i> <?php echo htmlspecialchars_decode(esc_attr($events_time));?></span>
            									<span> <i class="far fa-users"></i> <?php echo htmlspecialchars_decode(esc_attr($events_user));?></span>
            								</div>
            								<p><?php echo htmlspecialchars_decode(esc_attr($events_excerpt));?></p>
            								<a class="btn" href="<?php the_permalink();?>"><span class="btn-text"><?php if(isset($anondho_redux_demo['book_ticket'])){?>
                                        <?php echo htmlspecialchars_decode(esc_attr($anondho_redux_demo['book_ticket']));?>
                                        <?php }else{ ?>
                                        <?php echo esc_html__( 'Book Ticket', 'anondho' );}?></span> <span class="btn-border"></span></a>
            							</div>
            						</div>
            					</div>
            					<?php   
				        endwhile; 
				        wp_reset_postdata();
				    ?>
            			</div>
            		</div>
            	</div>

		<?php elseif( $chose_style == 'upcoming_home_3' ): ?>
			
			<?php if ( '' !== $settings['image_1_home_3']['url'] ): ?>
            <div class="upcominng-events-area pt-130 pb-100 pos-rel" style="background-image:url(<?php echo wp_kses_post($settings['image_1_home_3']['url']); ?>)">
            	<?php endif; ?>	
            	<?php if (( '' !== $settings['image_2_home_3']['url'] ) && ( $settings['show_image'] )): ?>
                <div class="shape d-none d-xl-block">
                    <div class="shape-item up-01 rotateme"><img src="<?php echo wp_kses_post($settings['image_2_home_3']['url']); ?>" alt=""></div>
                </div>
                <?php endif; ?>	
                <div class="container">
                    <div class="row">
                        <div class="col-xl-7 col-lg-7">
                            <div class="counting-wrapper mb-30">
                                <div class="area-title-light pb-70">
                                	<?php if (( '' !== $settings['heading_home_3'] ) && ( $settings['show_title'] )): ?>
                                    <h1><?php echo wp_kses_post($settings['heading_home_3']); ?></h1>
                                    <?php endif; ?>
                                    <?php if ( '' !== $settings['sub_heading_home_3'] ): ?>	
                                    <p><?php echo wp_kses_post($settings['sub_heading_home_3']); ?></p>
                                    <?php endif; ?>
                                </div>
                                <div class="counting-text">
                                	<?php if (( '' !== $settings['content_home_3'] ) && ( $settings['show_content'] )): ?>	
                                    <h1><?php echo wp_kses_post($settings['content_home_3']); ?></h1>
                                    <?php endif; ?>
                                    <?php if ( '' !== $settings['showtime_home_3'] ) : ?>
                                    <div class="deal-count">
                                        <div class="deal-time" data-countdown="<?php echo wp_kses_post($settings['showtime_home_3']); ?>"></div>
                                    </div>
                                    <?php endif; ?>
                                    <?php if (( '' !== $settings['button_home_3'] ) && ( $settings['show_button'] )): ?>
                                    <a class="btn pink-btn" href="<?php echo wp_kses_post($settings['link_home_3']); ?>"><span class="btn-text"><?php echo wp_kses_post($settings['button_home_3']); ?></span> <span class="btn-border"></span></a>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                        <div class="col-xl-5 col-lg-5">
                            <div class="upcoming-active owl-carousel">
                            	<?php 
                            	$args = new \WP_Query(array(   
                            		'post_type' => 'events', 
                            	));  
                            	$i = 1;
                            	while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
                            		$i++;

                            		$events_time = get_post_meta(get_the_ID(),'_cmb_events_time', true); 
                            		$events_date = get_post_meta(get_the_ID(),'_cmb_events_date', true); 
                            		$events_user = get_post_meta(get_the_ID(),'_cmb_events_user', true); 
                            		$events_price = get_post_meta(get_the_ID(),'_cmb_events_price', true); 
                            		$events_excerpt = get_post_meta(get_the_ID(),'_cmb_events_excerpt', true); 
                            		?>
                                <div class="upcoming-event-wrapper upcoming-2-event mb-30">
                                    <div class="upcoming-event-img">
                                        <a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt=""></a>
                                        <div class="up-tag">
                                            <span><?php echo htmlspecialchars_decode(esc_attr($events_price));?></span>
                                        </div>
                                    </div>
                                    <div class="upcoming-text">
                                        <h3><a href="<?php the_permalink();?>"><?php the_title();?></a></h3>
                                        <div class="up-event-meta">
                                            <span> <i class="far fa-calendar-alt"></i> <?php echo htmlspecialchars_decode(esc_attr($events_date));?></span>
                                            <span> <i class="far fa-clock"></i> <?php echo htmlspecialchars_decode(esc_attr($events_time));?></span>
                                            <span> <i class="far fa-users"></i> <?php echo htmlspecialchars_decode(esc_attr($events_user));?></span>
                                        </div>
                                        <p><?php echo htmlspecialchars_decode(esc_attr($events_excerpt));?> </p>
                                        <a class="btn" href="<?php the_permalink();?>"><span class="btn-text"><?php if(isset($anondho_redux_demo['book_ticket'])){?>
                                        <?php echo htmlspecialchars_decode(esc_attr($anondho_redux_demo['book_ticket']));?>
                                        <?php }else{ ?>
                                        <?php echo esc_html__( 'View Details', 'anondho' );}?></span> <span class="btn-border"></span></a>
                                    </div>
                                </div>
                                <?php   
				        endwhile; 
				        wp_reset_postdata();
				    ?>
                                
                            </div>
                        </div>
                    </div>
                </div>
            </div>
<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           $('.upcoming-active').owlCarousel({

		loop: true,

		nav: false,

		autoplay: true,

		smartSpeed:250,

		dots: false,

		navText: ['<i class="far fa-long-arrow-alt-left"></i>', '<i class="far fa-long-arrow-alt-right"></i>'],

		responsive: {

			0: {

				items: 1,

				nav: false,

				dots: false,

			},

			576: {

				items: 1

			},

			768: {

				items: 1

			},

			992: {

				items: 1

			},

			1200: {

				items: 1

			}

		}

	})
        
        
    </script>   
    <?php } ?>
        <?php elseif( $chose_style == 'upcoming_style_4' ): ?>
        	<?php if ( '' !== $settings['image_1_event']['url'] ): ?>
			<div class="upcominng-events-area pt-130 pb-100 pos-rel" style="background-image:url(<?php echo wp_kses_post($settings['image_1_event']['url']); ?>)">
			<?php endif; ?>
			<?php if (( '' !== $settings['image_2_event']['url'] ) && ( $settings['show_image'] )): ?>
                <div class="shape d-none d-xl-block">
                    <div class="shape-item up-02 rotateme"><img src="<?php echo wp_kses_post($settings['image_2_event']['url']); ?>" alt=""></div>
                </div>
            <?php endif; ?>
                <div class="container">
                    <div class="row">
                        <div class="col-xl-7 col-lg-7">
                            <div class="counting-wrapper mb-30">
                                <div class="upcoming-title">
                                	<?php if (( '' !== $settings['sub_event'] ) && ( $settings['show_content'] )): ?>
                                    <span><?php echo wp_kses_post($settings['sub_event']); ?></span>
                                    <?php endif; ?>
                                    <?php if (( '' !== $settings['heading_event'] ) && ( $settings['show_title'] )): ?>
                                    <h1><?php echo wp_kses_post($settings['heading_event']); ?></h1>
                                    <?php endif; ?>
                                </div>
                                <div class="counting-text counting-2-text">
                                	<?php if ( '' !== $settings['showtime_event'] ) : ?>
                                    <div class="deal-count">
                                        <div class="deal-time" data-countdown="<?php echo wp_kses_post($settings['showtime_event']); ?>"></div>
                                    </div>
                                    <?php endif; ?>
                                    <?php if (( '' !== $settings['button_event'] ) && ( $settings['show_button'] )): ?>
                                    <a class="btn" href="<?php echo wp_kses_post($settings['link_event']); ?>"><span class="btn-text"><?php echo wp_kses_post($settings['button_event']); ?></span> <span class="btn-border"></span></a>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                        <div class="col-xl-5 col-lg-5">
                        	<div class="upcoming-active owl-carousel">
                        	<?php 
                        	$args = new \WP_Query(array(   
                        		'post_type' => 'events', 
                        	));  
                        	$i = 1;
                        	while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
                        		$i++;

                        		$events_time = get_post_meta(get_the_ID(),'_cmb_events_time', true); 
                        		$events_date = get_post_meta(get_the_ID(),'_cmb_events_date', true); 
                        		$events_user = get_post_meta(get_the_ID(),'_cmb_events_user', true); 
                        		$events_price = get_post_meta(get_the_ID(),'_cmb_events_price', true); 
                        		$events_excerpt = get_post_meta(get_the_ID(),'_cmb_events_excerpt', true); 
                        		?>
                        		<div class="upcoming-event-wrapper upcoming-2-event mb-30">
                        			<div class="upcoming-event-img">
                        				<a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt=""></a>
                        				<div class="up-tag">
                        					<span><?php echo htmlspecialchars_decode(esc_attr($events_price));?></span>
                        				</div>
                        			</div>
                        			<div class="upcoming-text">
                        				<h3><a href="<?php the_permalink();?>"><?php the_title();?></a></h3>
                        				<div class="up-event-meta">
                        					<span> <i class="far fa-calendar-alt"></i> <?php echo htmlspecialchars_decode(esc_attr($events_date));?></span>
                        					<span> <i class="far fa-clock"></i> <?php echo htmlspecialchars_decode(esc_attr($events_time));?></span>
                        					<span> <i class="far fa-users"></i> <?php echo htmlspecialchars_decode(esc_attr($events_user));?></span>
                        				</div>
                        				<p><?php echo htmlspecialchars_decode(esc_attr($events_excerpt));?> </p>
                        				<a class="btn" href="<?php the_permalink();?>"><span class="btn-text"><?php if(isset($anondho_redux_demo['book_ticket'])){?>
                        					<?php echo htmlspecialchars_decode(esc_attr($anondho_redux_demo['book_ticket']));?>
                        				<?php }else{ ?>
                        					<?php echo esc_html__( 'View Details', 'anondho' );}?></span> <span class="btn-border"></span></a>
                        				</div>
                        			</div>
                        			<?php   
                        		endwhile; 
                        		wp_reset_postdata();
                        		?>
                        	</div>
                        </div>
                    </div>
                </div>
            </div>
			<?php if (is_admin()) { ?>
    <script type="text/javascript">
    
        
           $('.upcoming-active').owlCarousel({

		loop: true,

		nav: false,

		autoplay: true,

		smartSpeed:250,

		dots: false,

		navText: ['<i class="far fa-long-arrow-alt-left"></i>', '<i class="far fa-long-arrow-alt-right"></i>'],

		responsive: {

			0: {

				items: 1,

				nav: false,

				dots: false,

			},

			576: {

				items: 1

			},

			768: {

				items: 1

			},

			992: {

				items: 1

			},

			1200: {

				items: 1

			}

		}

	})
        
        
    </script>   
    <?php } ?>
            <?php elseif( $chose_style == 'upcoming_style_5' ): ?>
			<div class="upcoming-area pb-100">
				<div class="container">
					<div class="row">
						<div class="col-xl-8 col-lg-8 offset-lg-2 offset-xl-2">
							 <?php if (( '' !== $settings['heading'] ) && ( $settings['show_title'] )): ?>
							<div class="area-title text-center pb-75">
								<span></span>
							<h1><?php echo wp_kses_post($settings['heading']); ?></h1>
							<?php endif; ?>	
                                <?php if (( '' !== $settings['sub_heading'] ) && ( $settings['show_content'] )): ?>
							<p><?php echo wp_kses_post($settings['sub_heading']); ?></p>
							</div>
							<?php endif; ?>	
						</div>
					</div>
            			<div class="row">
            				<?php 
            				$args = new \WP_Query(array(   
            					'post_type' => 'events', 
            				));  
            				$i = 1;
            				while ($wp_query -> have_posts()) : $wp_query -> the_post(); 
            					$i++;

            					$events_time = get_post_meta(get_the_ID(),'_cmb_events_time', true); 
            					$events_date = get_post_meta(get_the_ID(),'_cmb_events_date', true); 
            					$events_user = get_post_meta(get_the_ID(),'_cmb_events_user', true); 
            					$events_price = get_post_meta(get_the_ID(),'_cmb_events_price', true); 
            					$events_excerpt = get_post_meta(get_the_ID(),'_cmb_events_excerpt', true); 
            					?>

            					<div class="col-xl-4 col-lg-6 col-md-6">
            						<div class="upcoming-event-wrapper mb-30">
            							<div class="upcoming-event-img">
            								<a href="<?php the_permalink();?>"><img src="<?php echo wp_get_attachment_url(get_post_thumbnail_id());?>" alt=""></a>
            								<div class="up-tag">
            									<span><?php echo htmlspecialchars_decode(esc_attr($events_price));?></span>
            								</div>
            							</div>
            							<div class="upcoming-text">
            								<h3><a href="<?php the_permalink();?>"><?php the_title();?></a></h3>
            								<div class="up-event-meta">
            									<span> <i class="far fa-calendar-alt"></i> <?php echo htmlspecialchars_decode(esc_attr($events_date));?></span>
            									<span> <i class="far fa-clock"></i> <?php echo htmlspecialchars_decode(esc_attr($events_time));?></span>
            									<span> <i class="far fa-users"></i> <?php echo htmlspecialchars_decode(esc_attr($events_user));?></span>
            								</div>
            								<p><?php echo htmlspecialchars_decode(esc_attr($events_excerpt));?></p>
            								<a class="btn" href="<?php the_permalink();?>"><span class="btn-text"><?php if(isset($anondho_redux_demo['book_ticket'])){?>
                                        <?php echo htmlspecialchars_decode(esc_attr($anondho_redux_demo['book_ticket']));?>
                                        <?php }else{ ?>
                                        <?php echo esc_html__( 'Book Ticket', 'anondho' );}?></span> <span class="btn-border"></span></a>
            							</div>
            						</div>
            					</div>
            					<?php   
				        endwhile; 
				        wp_reset_postdata();
				    ?>
            			</div>
            		</div>
            	</div>
               <?php endif; ?>

	<?php
	}

}